@@ -105,7 +105,7 @@ int main(int argc, char **argv)
     AjPFeattabOut featout = NULL;
 
 
-    ajGraphInit("cpgplot",argc,argv);
+    embInit("cpgplot",argc,argv);
 
     seqall    = ajAcdGetSeqall("sequence");
     window    = ajAcdGetInt("window");
@@ -173,7 +173,7 @@ int main(int argc, char **argv)
 
     if(mult)
     {
-	ajGraphCloseWin();
+	ajGraphicsClose();
 	ajGraphxyDel(&mult);
     }
 
@@ -524,9 +524,9 @@ static void cpgplot_plotit(const char *seq,
 			   AjBool dopc, AjPGraph graphs)
 
 {
-    AjPGraphPlpData tmGraph  = NULL;
-    AjPGraphPlpData tmGraph2 = NULL;
-    AjPGraphPlpData tmGraph3 = NULL;
+    AjPGraphdata tmGraph  = NULL;
+    AjPGraphdata tmGraph2 = NULL;
+    AjPGraphdata tmGraph3 = NULL;
     float *tmp = NULL;
     ajint i;
     float min = 0.;
@@ -536,10 +536,10 @@ static void cpgplot_plotit(const char *seq,
 
     if(doobsexp)
     {
-	tmGraph2 = ajGraphPlpDataNew();
-	ajGraphPlpDataSetTitleC(tmGraph2,"Observed vs Expected");
-	ajGraphPlpDataSetXTitleC(tmGraph2,"Base number");
-	ajGraphPlpDataSetYTitleC(tmGraph2,"Obs/Exp");
+	tmGraph2 = ajGraphdataNew();
+	ajGraphdataSetTitleC(tmGraph2,"Observed vs Expected");
+	ajGraphdataSetXlabelC(tmGraph2,"Base number");
+	ajGraphdataSetYlabelC(tmGraph2,"Obs/Exp");
 
 	min = 64000.;
 	max = -64000.;
@@ -549,31 +549,31 @@ static void cpgplot_plotit(const char *seq,
 	    max = (max>obsexp[i]) ? max : obsexp[i];
 	}
 
-	ajGraphPlpDataSetMaxMin(tmGraph2,(float)begin,(float)begin+len-1,
+	ajGraphdataSetMinmax(tmGraph2,(float)begin,(float)begin+len-1,
 			       min,max);
-	ajGraphPlpDataSetMaxima(tmGraph2,(float)begin,(float)begin+len-1,
+	ajGraphdataSetTruescale(tmGraph2,(float)begin,(float)begin+len-1,
 			       0.0,max);
-	ajGraphPlpDataSetTypeC(tmGraph2,"Multi 2D Plot");
+	ajGraphdataSetTypeC(tmGraph2,"Multi 2D Plot");
 
-	ajGraphxySetXStart(graphs,(float)begin);
-	ajGraphxySetXEnd(graphs,(float)(begin+len-1));
+	ajGraphxySetXstartF(graphs,(float)begin);
+	ajGraphxySetXendF(graphs,(float)(begin+len-1));
 
-	ajGraphxySetYStart(graphs,0.0);
-	ajGraphxySetYEnd(graphs,obsexpmax);
-	ajGraphxySetXRangeII(graphs,begin,begin+len-1);
-	ajGraphxySetYRangeII(graphs,0,(ajint)(obsexpmax+1.0));
+	ajGraphxySetYstartF(graphs,0.0);
+	ajGraphxySetYendF(graphs,obsexpmax);
+	ajGraphxySetXrangeII(graphs,begin,begin+len-1);
+	ajGraphxySetYrangeII(graphs,0,(ajint)(obsexpmax+1.0));
 
-	ajGraphPlpDataCalcXY(tmGraph2,len,(float)begin,1.0,obsexp);
+	ajGraphdataCalcXY(tmGraph2,len,(float)begin,1.0,obsexp);
 	ajGraphDataReplaceI(graphs,tmGraph2,igraph++);
 	tmGraph2 = NULL;
     }
 
     if(dopc)
     {
-	tmGraph3 = ajGraphPlpDataNew();
-	ajGraphPlpDataSetTitleC(tmGraph3,"Percentage");
-	ajGraphPlpDataSetXTitleC(tmGraph3,"Base number");
-	ajGraphPlpDataSetYTitleC(tmGraph3,"Percentage");
+	tmGraph3 = ajGraphdataNew();
+	ajGraphdataSetTitleC(tmGraph3,"Percentage");
+	ajGraphdataSetXlabelC(tmGraph3,"Base number");
+	ajGraphdataSetYlabelC(tmGraph3,"Percentage");
 
 	min = 64000.;
 	max = -64000.;
@@ -583,20 +583,20 @@ static void cpgplot_plotit(const char *seq,
 	    max = (max>xypc[i]) ? max : xypc[i];
 	}
 
-	ajGraphPlpDataSetMaxMin(tmGraph3,(float)begin,(float)begin+len-1,
+	ajGraphdataSetMinmax(tmGraph3,(float)begin,(float)begin+len-1,
 			       min,max);
-	ajGraphPlpDataSetMaxima(tmGraph3,(float)begin,(float)begin+len-1,
+	ajGraphdataSetTruescale(tmGraph3,(float)begin,(float)begin+len-1,
 			      0.0,max);
-	ajGraphPlpDataSetTypeC(tmGraph3,"Multi 2D Plot");
+	ajGraphdataSetTypeC(tmGraph3,"Multi 2D Plot");
 
-	ajGraphxySetXStart(graphs,(float)begin);
-	ajGraphxySetXEnd(graphs,(float)(begin+len-1));
-	ajGraphxySetYStart(graphs,0);
-	ajGraphxySetYEnd(graphs,100);
-	ajGraphxySetXRangeII(graphs,begin,begin+len-1);
-	ajGraphxySetYRangeII(graphs,0,100);
+	ajGraphxySetXstartF(graphs,(float)begin);
+	ajGraphxySetXendF(graphs,(float)(begin+len-1));
+	ajGraphxySetYstartF(graphs,0);
+	ajGraphxySetYendF(graphs,100);
+	ajGraphxySetXrangeII(graphs,begin,begin+len-1);
+	ajGraphxySetYrangeII(graphs,0,100);
 
-	ajGraphPlpDataCalcXY(tmGraph3,len,(float)begin,1.0,xypc);
+	ajGraphdataCalcXY(tmGraph3,len,(float)begin,1.0,xypc);
 	ajGraphDataReplaceI(graphs,tmGraph3,igraph++);
 	tmGraph3 = NULL;
     }
@@ -612,28 +612,28 @@ static void cpgplot_plotit(const char *seq,
 		tmp[i] = 0.0;
 	}
 
-	tmGraph = ajGraphPlpDataNew();
-	ajGraphPlpDataSetTitleC(tmGraph,"Putative Islands");
-	ajGraphPlpDataSetXTitleC(tmGraph,"Base Number");
-	ajGraphPlpDataSetYTitleC(tmGraph,"Threshold");
+	tmGraph = ajGraphdataNew();
+	ajGraphdataSetTitleC(tmGraph,"Putative Islands");
+	ajGraphdataSetXlabelC(tmGraph,"Base Number");
+	ajGraphdataSetYlabelC(tmGraph,"Threshold");
 
-	ajGraphPlpDataSetMaxMin(tmGraph,(float)begin,(float)begin+len-1,
+	ajGraphdataSetMinmax(tmGraph,(float)begin,(float)begin+len-1,
 			       0.,1.);
-	ajGraphPlpDataSetTypeC(tmGraph,"Multi 2D Plot");
+	ajGraphdataSetTypeC(tmGraph,"Multi 2D Plot");
 
 
-	ajGraphxySetXStart(graphs,(float)begin);
-	ajGraphxySetXEnd(graphs,(float)(begin+len-1));
-	ajGraphxySetYStart(graphs,0);
-	ajGraphxySetYEnd(graphs,2);
-	ajGraphxySetXRangeII(graphs,begin,begin+len-1);
-	ajGraphxySetYRangeII(graphs,0,2);
-	ajGraphPlpDataSetMaxMin(tmGraph,(float)begin,(float)(begin+len-1),
+	ajGraphxySetXstartF(graphs,(float)begin);
+	ajGraphxySetXendF(graphs,(float)(begin+len-1));
+	ajGraphxySetYstartF(graphs,0);
+	ajGraphxySetYendF(graphs,2);
+	ajGraphxySetXrangeII(graphs,begin,begin+len-1);
+	ajGraphxySetYrangeII(graphs,0,2);
+	ajGraphdataSetMinmax(tmGraph,(float)begin,(float)(begin+len-1),
 			       (float) 0.0, (float) 1.2);
-	ajGraphPlpDataSetMaxima(tmGraph,(float)begin,(float)(begin+len-1),
+	ajGraphdataSetTruescale(tmGraph,(float)begin,(float)(begin+len-1),
 			       (float) 0.0, (float) 1.0);
 
-	ajGraphPlpDataCalcXY(tmGraph,len,(float)begin,1.0,tmp);
+	ajGraphdataCalcXY(tmGraph,len,(float)begin,1.0,tmp);
 	ajGraphDataReplaceI(graphs,tmGraph,igraph++);
 	tmGraph = NULL;
     }
@@ -642,7 +642,7 @@ static void cpgplot_plotit(const char *seq,
     if(docg || dopc || doobsexp)
     {
 	ajGraphSetTitleC(graphs,seq);
-	ajGraphxySetOverLap(graphs,ajFalse);
+	ajGraphxySetflagOverlay(graphs,ajFalse);
 	ajGraphxyDisplay(graphs, AJFALSE);
     }
 
@@ -724,7 +724,7 @@ static void cpgplot_dumpfeatout(AjPFeattabOut featout, const AjBool *thresh,
 			    score, strand, frame);
     }
     ajFeatSortByStart(feattable);
-    ajFeatWrite (featout, feattable);
+    ajFeattableWrite (featout, feattable);
     ajFeattableDel(&feattable);
 
     ajStrDel(&source);
