@@ -81,7 +81,7 @@ int main(int argc, char **argv)
     float flen2;
     ajuint tui;
     
-    ajGraphInit("dotpath", argc, argv);
+    embInit("dotpath", argc, argv);
     
     wordlen  = ajAcdGetInt("wordsize");
     seq1     = ajAcdGetSeq("asequence");
@@ -116,14 +116,14 @@ int main(int argc, char **argv)
     ajGraphOpenWin(graph, (float)0.0-ymargin,(max*(float)1.35)+ymargin,
 		   (float)0.0-xmargin,(float)max+xmargin);
     
-    ajGraphSetCharScale(0.5);
+    ajGraphicsSetCharscale(0.5);
     
     /* display the overlapping matches in red */
     if(overlaps && ajListGetLength(matchlist))
     {
-	oldcolour = ajGraphSetFore(RED);
+	oldcolour = ajGraphicsSetFgcolour(RED);
 	dotpath_plotMatches(matchlist);
-	ajGraphSetFore(oldcolour);  /* restore colour we were using */
+	ajGraphicsSetFgcolour(oldcolour);  /* restore colour we were using */
     }
     
     /* get the minimal set of overlapping matches */
@@ -137,7 +137,7 @@ int main(int argc, char **argv)
     
     if(boxit)
     {
-	ajGraphRect( 0.0,0.0,flen1,flen2);
+	ajGraphicsDrawposRect( 0.0,0.0,flen1,flen2);
 	i = 0;
 	while(acceptableticksx[i]*numbofticks < flen1)
 	    i++;
@@ -149,27 +149,29 @@ int main(int argc, char **argv)
 
 	ticklen = xmargin*(float)0.1;
 	onefifth  = xmargin*(float)0.2;
-	ajGraphTextMid(flen1*(float)0.5,(float)0.0-(onefifth*(float)3.),
-		       ajGraphGetYTitleC(graph));
+	ajGraphicsDrawposTextAtmid(flen1*(float)0.5,
+                                   (float)0.0-(onefifth*(float)3.),
+                                   ajGraphGetYlabelC(graph));
 
 	if(len2/len1 > 10 )
 	{
 	    /* a lot smaller then just label start and end */
-	    ajGraphLine((float)0.0,(float)0.0,(float)0.0,(float)0.0-ticklen);
+	    ajGraphicsDrawposLine((float)0.0,(float)0.0,
+                                  (float)0.0,(float)0.0-ticklen);
 	    sprintf(ptr,"%d",ajSeqGetOffset(seq1));
-	    ajGraphTextMid((float)0.0,(float)0.0-(onefifth),ptr);
+	    ajGraphicsDrawposTextAtmid((float)0.0,(float)0.0-(onefifth),ptr);
 
-	    ajGraphLine(flen1,(float)0.0,
+	    ajGraphicsDrawposLine(flen1,(float)0.0,
 			flen1,(float)0.0-ticklen);
 	    sprintf(ptr,"%d",len1+ajSeqGetOffset(seq1));
-	    ajGraphTextMid(flen1,(float)0.0-(onefifth),ptr);
+	    ajGraphicsDrawposTextAtmid(flen1,(float)0.0-(onefifth),ptr);
 	}
 	else
 	    for(k=0.0;k<len1;k+=tickgap)
 	    {
-		ajGraphLine(k,(float)0.0,k,(float)0.0-ticklen);
+		ajGraphicsDrawposLine(k,(float)0.0,k,(float)0.0-ticklen);
 		sprintf(ptr,"%d",(ajint)k+ajSeqGetOffset(seq1));
-		ajGraphTextMid( k,(float)0.0-(onefifth),ptr);
+		ajGraphicsDrawposTextAtmid( k,(float)0.0-(onefifth),ptr);
 	    }
 
 	i = 0;
@@ -179,32 +181,36 @@ int main(int argc, char **argv)
 	tickgap   = (float) acceptableticks[i];
 	ticklen   = ymargin*(float)0.1;
 	onefifth  = ymargin*(float)0.2;
-	ajGraphTextLine((float)0.0-(onefifth*(float)4.),flen2*(float)0.5,
-			(float)0.0-(onefifth*(float)4.),flen2,
-			ajGraphGetXTitleC(graph),(float)0.5);
+	ajGraphicsDrawposTextAtlineJustify((float)0.0-(onefifth*(float)4.),
+                                           flen2*(float)0.5,
+                                           (float)0.0-(onefifth*(float)4.),
+                                           flen2,
+                                           ajGraphGetXlabelC(graph),
+                                           (float)0.5);
 
 	if(len1/len2 > 10 )
 	{
 	    /* a lot smaller then just label start and end */
-	    ajGraphLine((float)0.0,(float)0.0,(float)0.0-ticklen,(float)0.0);
+	    ajGraphicsDrawposLine((float)0.0,(float)0.0,
+                                  (float)0.0-ticklen,(float)0.0);
 	    sprintf(ptr,"%d",ajSeqGetOffset(seq2));
-	    ajGraphTextEnd( (float)0.0-(onefifth),(float)0.0,ptr);
+	    ajGraphicsDrawposTextAtend( (float)0.0-(onefifth),(float)0.0,ptr);
 
-	    ajGraphLine((float)0.0,flen2,
+	    ajGraphicsDrawposLine((float)0.0,flen2,
 			(float)0.0-ticklen,flen2);
 	    sprintf(ptr,"%d",len2+ajSeqGetOffset(seq2));
-	    ajGraphTextEnd((float)0.0-(onefifth),flen2,ptr);
+	    ajGraphicsDrawposTextAtend((float)0.0-(onefifth),flen2,ptr);
 	}
 	else
 	    for(k=0.0;k<len2;k+=tickgap)
 	    {
-		ajGraphLine((float)0.0,k,(float)0.0-ticklen,k);
+		ajGraphicsDrawposLine((float)0.0,k,(float)0.0-ticklen,k);
 		sprintf(ptr,"%d",(ajint)k+ajSeqGetOffset(seq2));
-		ajGraphTextEnd( (float)0.0-(onefifth),k,ptr);
+		ajGraphicsDrawposTextAtend( (float)0.0-(onefifth),k,ptr);
 	    }
     }
 
-    ajGraphClose();
+    ajGraphicsClose();
 
     embWordFreeTable(&seq1MatchTable);
     if(matchlist)
@@ -253,7 +259,7 @@ static void dotpath_drawPlotlines(void *x, void *cl)
     x2 += p->length;
     y2 += (PLFLT)p->length;
 
-    ajGraphLine(x1, y1, x2, y2);
+    ajGraphicsDrawposLine(x1, y1, x2, y2);
 
     return;
 }
