@@ -274,7 +274,7 @@ int main(int argc, char **argv)
 	mattab = jaspscan_ReadCoreList(jaspdir);
 
     ajFmtPrintS(&head,"Database scanned: %S  Threshold: %.3f",jaspdir,thresh);
-    ajReportSetHeader(report,head);
+    ajReportSetHeaderS(report,head);
     
     while(ajSeqallNext(seqall, &seq))
     {
@@ -660,7 +660,7 @@ static void jaspscan_scan(const AjPStr seq, const ajuint begin,
 	}
 
 
-	scorepc = (sum * 100.) / maxscore;
+	scorepc = (sum * (float)100.) / maxscore;
 
 
 	if(scorepc >= threshold)
@@ -704,7 +704,7 @@ static void jaspscan_scan(const AjPStr seq, const ajuint begin,
 	    }
 
 
-	    scorepc = (sum * 100.) / maxscore;
+	    scorepc = (sum * (float)100.) / maxscore;
 
 
 	    if(scorepc >= threshold)
