@@ -105,13 +105,13 @@ static void lindna_InterBlocks(float xDraw, float yDraw, float BlockHeight,
 			       float From, float To, const AjPStr InterSymbol,
 			       ajint Colour);
 
-static void lindna_DrawArrowHeadsOnLine(float xDraw, float yDraw, float Height,
+static void lindna_DrawArrowHeadsOnline(float xDraw, float yDraw, float Height,
 					float Length, ajint Way);
 
-static void lindna_DrawBracketsOnLine(float xDraw, float yDraw, float Height,
+static void lindna_DrawBracketsOnline(float xDraw, float yDraw, float Height,
 				      float Length, ajint Way);
 
-static void lindna_DrawBarsOnLine(float xDraw, float yDraw, float Height);
+static void lindna_DrawBarsOnline(float xDraw, float yDraw, float Height);
 
 static void lindna_HorTextPile(float x, float y, const AjPStr Name,
 			       float postext,
@@ -217,7 +217,7 @@ int main(int argc, char **argv)
     ajint maxlabels;
 
     /* read the ACD file for graphical programs */
-    ajGraphInit("lindna", argc, argv);
+    embInit("lindna", argc, argv);
 
     /* array size limits */
     maxgroups = ajAcdGetInt("maxgroups");
@@ -266,8 +266,8 @@ int main(int argc, char **argv)
     AJCNEW0(Name, maxgroups);
  
     /* length and height of text */
-    TextHeight = 20*ajAcdGetFloat("textheight");
-    TextLength = 40*ajAcdGetFloat("textlength");
+    TextHeight = 3*ajAcdGetFloat("textheight");
+    TextLength = 7*ajAcdGetFloat("textlength");
 
     /* open the window in which the graphics will be drawn */
     DrawLength = 500;
@@ -277,7 +277,7 @@ int main(int argc, char **argv)
     Width = DrawLength + 2*Border + Margin;
     Height = DrawLength + 2*Border;
 
-    ajGraphSetTitlePlus(graph, ajFileGetNameS(infile));
+    ajGraphAppendTitleS(graph, ajFileGetNameS(infile));
 
     ajGraphOpenWin(graph, 0, Width, 0, Height*(float)1.1);
 
@@ -402,11 +402,11 @@ int main(int argc, char **argv)
 	if(charsize<minsize)
 	    minsize = charsize;
     }
-    ajGraphSetDefCharSize(minsize);
+    ajGraphicsSetDefcharsize(minsize);
 
 
     /* find whether horizontal text strings overlap within a group */
-    postext = (ajGraphTextHeight(0, 0, 1, 0)+3)*ajAcdGetFloat("postext");
+    postext = (ajGraphicsCalcTextheight()+3)*ajAcdGetFloat("postext");
     for(i=0; i<NumGroups; i++)
 	AdjustMax[i] = lindna_OverlapTextGroup(Name[i], Style[i], TextOri[i],
 					       NumLabels[i], From[i], To[i],
@@ -462,7 +462,7 @@ int main(int argc, char **argv)
 	if(charsize<minsize)
 	    minsize = charsize;
     }
-    ajGraphSetDefCharSize(minsize);
+    ajGraphicsSetDefcharsize(minsize);
 
 
     /* the ruler having been resized, recompute its height */
@@ -508,7 +508,7 @@ int main(int argc, char **argv)
     ajStrDel(&BlockType);
     ajStrDel(&InterSymbol);
 
-    ajGraphCloseWin();
+    ajGraphicsClose();
     ajGraphxyDel(&graph);
 
     for(i=0;i<NumGroups;i++)
@@ -584,11 +584,11 @@ static float lindna_TextRuler(float Start, float End, ajint GapSize,
 
     ajStrFromInt(&string, (ajint)Start);
     if(TextOri=='H')
-	charsize = ajGraphFitTextOnLine(0, 0, TextLength, 0,
-					ajStrGetPtr(string), TextHeight);
+	charsize = ajGraphicsCalcCharsize(0, 0, TextLength, 0,
+                                          ajStrGetPtr(string), TextHeight);
     else
-	charsize = ajGraphFitTextOnLine(0, 0, 0, TextLength,
-					ajStrGetPtr(string), TextHeight);
+	charsize = ajGraphicsCalcCharsize(0, 0, 0, TextLength,
+                                          ajStrGetPtr(string), TextHeight);
     if(charsize < minsize)
 	minsize = charsize;
 
@@ -598,11 +598,13 @@ static float lindna_TextRuler(float Start, float End, ajint GapSize,
 	{
 	    ajStrFromInt(&string, i);
 	    if(TextOri=='H')
-		charsize = ajGraphFitTextOnLine(0, 0, TextLength, 0,
-						ajStrGetPtr(string), TextHeight);
+		charsize = ajGraphicsCalcCharsize(0, 0, TextLength, 0,
+                                                  ajStrGetPtr(string),
+                                                  TextHeight);
 	    else
-		charsize = ajGraphFitTextOnLine(0, 0, 0, TextLength,
-						ajStrGetPtr(string), TextHeight);
+		charsize = ajGraphicsCalcCharsize(0, 0, 0, TextLength,
+                                                  ajStrGetPtr(string),
+                                                  TextHeight);
 	    if(charsize < minsize)
 		minsize = charsize;
 	}
@@ -610,11 +612,11 @@ static float lindna_TextRuler(float Start, float End, ajint GapSize,
 
     ajStrFromInt(&string, (ajint)End);
     if(TextOri=='H')
-	charsize = ajGraphFitTextOnLine(0, 0, TextLength, 0,
-					ajStrGetPtr(string), TextHeight);
+	charsize = ajGraphicsCalcCharsize(0, 0, TextLength, 0,
+                                          ajStrGetPtr(string), TextHeight);
     else
-	charsize = ajGraphFitTextOnLine(0, 0, 0, TextLength,
-					ajStrGetPtr(string), TextHeight);
+	charsize = ajGraphicsCalcCharsize(0, 0, 0, TextLength,
+                                          ajStrGetPtr(string), TextHeight);
     if(charsize < minsize)
 	minsize = charsize;
 
@@ -655,7 +657,7 @@ static float lindna_HeightRuler(float Start, float End, ajint GapSize,
     RulerHeight = TickHeight+postext;
 
     if(TextOri=='H')
-	RulerHeight += ajGraphTextHeight(0, 0, 1, 0);
+	RulerHeight += ajGraphicsCalcTextheight();
     else
     {
 	ajStrFromInt(&string, (ajint)Start);
@@ -716,14 +718,14 @@ static void lindna_DrawRuler(float xDraw, float yDraw, float Start, float End,
 
     string = ajStrNew();
 
-    ajGraphSetFore(Colour);
+    ajGraphicsSetFgcolour(Colour);
 
-    ajGraphDrawLine(xDraw, yDraw, xDraw+DrawLength, yDraw);
+    ajGraphicsDrawposLine(xDraw, yDraw, xDraw+DrawLength, yDraw);
 
     /* set the molecule's start */
     ajStrFromInt(&string, (ajint)Start);
     if(TickLines)
-	ajGraphDrawLine(xDraw, Border, xDraw, yDraw);
+	ajGraphicsDrawposLine(xDraw, Border, xDraw, yDraw);
     lindna_DrawTicks(xDraw, yDraw, TickHeight, 0.0, string,
 		     postext, TextOri, 1, 0, Colour);
 
@@ -734,7 +736,7 @@ static void lindna_DrawRuler(float xDraw, float yDraw, float Start, float End,
 	{
 	    ajStrFromInt(&string, i);
 	    if(TickLines)
-		ajGraphDrawLine(xDraw+(float)1.0*(i-Start)/ReduceCoef,
+		ajGraphicsDrawposLine(xDraw+(float)1.0*(i-Start)/ReduceCoef,
 				Border, xDraw+(float)1.0*(i-Start)/ReduceCoef,
 				yDraw);
 	    lindna_DrawTicks(xDraw, yDraw, TickHeight,
@@ -746,7 +748,7 @@ static void lindna_DrawRuler(float xDraw, float yDraw, float Start, float End,
     /* set the molecule's end */
     ajStrFromInt(&string, (ajint)End);
     if(TickLines)
-	ajGraphDrawLine(xDraw+(float)1.0*RealLength/ReduceCoef, Border,
+	ajGraphicsDrawposLine(xDraw+(float)1.0*RealLength/ReduceCoef, Border,
 			xDraw+(float)1.0*RealLength/ReduceCoef, yDraw);
     lindna_DrawTicks(xDraw, yDraw, TickHeight,(float)1.0*RealLength/ReduceCoef,
 		     string, postext, TextOri, 1, 0,
@@ -792,9 +794,9 @@ static void lindna_DrawTicks(float xDraw, float yDraw, float TickHeight,
     x2Ticks = x1Ticks;
     y2Ticks = y1Ticks+TickHeight;
 
-    ajGraphSetFore(Colour);
+    ajGraphicsSetFgcolour(Colour);
 
-    ajGraphDrawLine(x1Ticks, y1Ticks, x2Ticks, y2Ticks);
+    ajGraphicsDrawposLine(x1Ticks, y1Ticks, x2Ticks, y2Ticks);
     if(NumNames!=0)
     {
 	if(TextOri=='H')
@@ -846,25 +848,25 @@ static void lindna_DrawBlocks(float xDraw, float yDraw, float BlockHeight,
     x2Blocks = xDraw+To;
     y2Blocks = y1Blocks-BlockHeight;
 
-    ajGraphSetFore(Colour);
+    ajGraphicsSetFgcolour(Colour);
 
     if(ajCharCmpCase(ajStrGetPtr(BlockType), "Open")==0)
     {
-	ajGraphRect(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
+	ajGraphicsDrawposRect(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
     }
     else if(ajCharCmpCase(ajStrGetPtr(BlockType), "Filled")==0)
     {
-	ajGraphRectFill(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
+	ajGraphicsDrawposRectFill(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
     }
     else
     {
-	ajGraphRectFill(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
-	ajGraphSetFore(0);
-	ajGraphRect(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
-	ajGraphSetFore(Colour);
+	ajGraphicsDrawposRectFill(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
+	ajGraphicsSetFgcolour(0);
+	ajGraphicsDrawposRect(x1Blocks, y1Blocks, x2Blocks, y2Blocks);
+	ajGraphicsSetFgcolour(Colour);
     }
 
-    /* ajGraphSetFore(0); */
+    /* ajGraphicsSetFgcolour(0); */
     if(NumNames!=0)
     {
 	if(TextOri=='H')
@@ -922,9 +924,9 @@ static void lindna_DrawRanges(float xDraw, float yDraw, float RangeHeight,
     y2Ranges = y1Ranges;
     yupper   = yDraw+((float)1.0*RangeHeight/(float)2.);
 
-    ajGraphSetFore(Colour);
+    ajGraphicsSetFgcolour(Colour);
 
-    ajGraphDrawLine(x1Ranges, y1Ranges, x2Ranges, y2Ranges);
+    ajGraphicsDrawposLine(x1Ranges, y1Ranges, x2Ranges, y2Ranges);
     if(NumNames!=0)
     {
 	if(TextOri=='H')
@@ -943,34 +945,34 @@ static void lindna_DrawRanges(float xDraw, float yDraw, float RangeHeight,
 	BoundaryLength = RangeHeight;
 
     if(FromSymbol=='<')
-	lindna_DrawArrowHeadsOnLine(x1Ranges, y1Ranges, RangeHeight,
+	lindna_DrawArrowHeadsOnline(x1Ranges, y1Ranges, RangeHeight,
 				    BoundaryLength, +1);
     if(FromSymbol=='>')
-	lindna_DrawArrowHeadsOnLine(x1Ranges, y1Ranges, RangeHeight,
+	lindna_DrawArrowHeadsOnline(x1Ranges, y1Ranges, RangeHeight,
 				    BoundaryLength, -1);
     if(FromSymbol=='[')
-	lindna_DrawBracketsOnLine(x1Ranges, y1Ranges, RangeHeight,
+	lindna_DrawBracketsOnline(x1Ranges, y1Ranges, RangeHeight,
 				  BoundaryLength, +1);
     if(FromSymbol==']')
-	lindna_DrawBracketsOnLine(x1Ranges, y1Ranges, RangeHeight,
+	lindna_DrawBracketsOnline(x1Ranges, y1Ranges, RangeHeight,
 				  BoundaryLength, -1);
     if(FromSymbol=='|')
-	lindna_DrawBarsOnLine(x1Ranges, y1Ranges, RangeHeight);
+	lindna_DrawBarsOnline(x1Ranges, y1Ranges, RangeHeight);
 
     if(ToSymbol=='<')
-	lindna_DrawArrowHeadsOnLine(x2Ranges, y2Ranges, RangeHeight,
+	lindna_DrawArrowHeadsOnline(x2Ranges, y2Ranges, RangeHeight,
 				    BoundaryLength, +1);
     if(ToSymbol=='>')
-	lindna_DrawArrowHeadsOnLine(x2Ranges, y2Ranges, RangeHeight,
+	lindna_DrawArrowHeadsOnline(x2Ranges, y2Ranges, RangeHeight,
 				    BoundaryLength, -1);
     if(ToSymbol=='[')
-	lindna_DrawBracketsOnLine(x2Ranges, y2Ranges, RangeHeight,
+	lindna_DrawBracketsOnline(x2Ranges, y2Ranges, RangeHeight,
 				  BoundaryLength, +1);
     if(ToSymbol==']')
-	lindna_DrawBracketsOnLine(x2Ranges, y2Ranges, RangeHeight,
+	lindna_DrawBracketsOnline(x2Ranges, y2Ranges, RangeHeight,
 				  BoundaryLength, -1);
     if(ToSymbol=='|')
-	lindna_DrawBarsOnLine(x2Ranges, y2Ranges, RangeHeight);
+	lindna_DrawBarsOnline(x2Ranges, y2Ranges, RangeHeight);
 
     return;
 }
@@ -1006,22 +1008,22 @@ static void lindna_InterBlocks(float xDraw, float yDraw, float BlockHeight,
     x2Inter = xDraw+To;
     y2Inter = y1Inter-BlockHeight;
 
-    ajGraphSetFore(Colour);
+    ajGraphicsSetFgcolour(Colour);
 
     if(ajCharCmpCase(ajStrGetPtr(InterSymbol), "Down")==0)
     {
-	ajGraphDrawLine(x1Inter, y1Inter, (x1Inter+x2Inter)/2, y2Inter);
-	ajGraphDrawLine((x1Inter+x2Inter)/2, y2Inter, x2Inter, y1Inter);
+	ajGraphicsDrawposLine(x1Inter, y1Inter, (x1Inter+x2Inter)/2, y2Inter);
+	ajGraphicsDrawposLine((x1Inter+x2Inter)/2, y2Inter, x2Inter, y1Inter);
     }
 
     if(ajCharCmpCase(ajStrGetPtr(InterSymbol), "Up")==0)
     {
-	ajGraphDrawLine(x1Inter, y2Inter, (x1Inter+x2Inter)/2, y1Inter);
-	ajGraphDrawLine((x1Inter+x2Inter)/2, y1Inter, x2Inter, y2Inter);
+	ajGraphicsDrawposLine(x1Inter, y2Inter, (x1Inter+x2Inter)/2, y1Inter);
+	ajGraphicsDrawposLine((x1Inter+x2Inter)/2, y1Inter, x2Inter, y2Inter);
     }
 
     if(ajCharCmpCase(ajStrGetPtr(InterSymbol), "Straight")==0)
-	ajGraphDrawLine(x1Inter, (y1Inter+y2Inter)/2, x2Inter,
+	ajGraphicsDrawposLine(x1Inter, (y1Inter+y2Inter)/2, x2Inter,
 			(y1Inter+y2Inter)/2);
 
     return;
@@ -1030,7 +1032,7 @@ static void lindna_InterBlocks(float xDraw, float yDraw, float BlockHeight,
 
 
 
-/* @funcstatic lindna_DrawArrowHeadsOnLine ************************************
+/* @funcstatic lindna_DrawArrowHeadsOnline ************************************
 **
 ** draw arrowheads on a line
 **
@@ -1042,7 +1044,7 @@ static void lindna_InterBlocks(float xDraw, float yDraw, float BlockHeight,
 ** @@
 ******************************************************************************/
 
-static void lindna_DrawArrowHeadsOnLine(float xDraw, float yDraw, float Height,
+static void lindna_DrawArrowHeadsOnline(float xDraw, float yDraw, float Height,
 					float Length, ajint Way)
 {
     float middle;
@@ -1051,14 +1053,14 @@ static void lindna_DrawArrowHeadsOnLine(float xDraw, float yDraw, float Height,
 
     if(Way==1)
     {
-	ajGraphDrawLine(xDraw, yDraw, xDraw+Length, yDraw+middle);
-	ajGraphDrawLine(xDraw, yDraw, xDraw+Length, yDraw-middle);
+	ajGraphicsDrawposLine(xDraw, yDraw, xDraw+Length, yDraw+middle);
+	ajGraphicsDrawposLine(xDraw, yDraw, xDraw+Length, yDraw-middle);
     }
 
     if(Way==-1)
     {
-	ajGraphDrawLine(xDraw, yDraw, xDraw-Length, yDraw+middle);
-	ajGraphDrawLine(xDraw, yDraw, xDraw-Length, yDraw-middle);
+	ajGraphicsDrawposLine(xDraw, yDraw, xDraw-Length, yDraw+middle);
+	ajGraphicsDrawposLine(xDraw, yDraw, xDraw-Length, yDraw-middle);
     }
 
     return;
@@ -1067,7 +1069,7 @@ static void lindna_DrawArrowHeadsOnLine(float xDraw, float yDraw, float Height,
 
 
 
-/* @funcstatic lindna_DrawBracketsOnLine **************************************
+/* @funcstatic lindna_DrawBracketsOnline **************************************
 **
 ** draw brackets on a line
 **
@@ -1079,7 +1081,7 @@ static void lindna_DrawArrowHeadsOnLine(float xDraw, float yDraw, float Height,
 ** @@
 ******************************************************************************/
 
-static void lindna_DrawBracketsOnLine(float xDraw, float yDraw, float Height,
+static void lindna_DrawBracketsOnline(float xDraw, float yDraw, float Height,
 				      float Length, ajint Way)
 {
     float middle;
@@ -1088,16 +1090,16 @@ static void lindna_DrawBracketsOnLine(float xDraw, float yDraw, float Height,
 
     if(Way==1)
     {
-	ajGraphDrawLine(xDraw, yDraw-middle, xDraw, yDraw+middle);
-	ajGraphDrawLine(xDraw, yDraw+middle, xDraw+Length, yDraw+middle);
-	ajGraphDrawLine(xDraw, yDraw-middle, xDraw+Length, yDraw-middle);
+	ajGraphicsDrawposLine(xDraw, yDraw-middle, xDraw, yDraw+middle);
+	ajGraphicsDrawposLine(xDraw, yDraw+middle, xDraw+Length, yDraw+middle);
+	ajGraphicsDrawposLine(xDraw, yDraw-middle, xDraw+Length, yDraw-middle);
     }
 
     if(Way==-1)
     {
-	ajGraphDrawLine(xDraw, yDraw-middle, xDraw, yDraw+middle);
-	ajGraphDrawLine(xDraw, yDraw+middle, xDraw-Length, yDraw+middle);
-	ajGraphDrawLine(xDraw, yDraw-middle, xDraw-Length, yDraw-middle);
+	ajGraphicsDrawposLine(xDraw, yDraw-middle, xDraw, yDraw+middle);
+	ajGraphicsDrawposLine(xDraw, yDraw+middle, xDraw-Length, yDraw+middle);
+	ajGraphicsDrawposLine(xDraw, yDraw-middle, xDraw-Length, yDraw-middle);
     }
 
     return;
@@ -1106,7 +1108,7 @@ static void lindna_DrawBracketsOnLine(float xDraw, float yDraw, float Height,
 
 
 
-/* @funcstatic lindna_DrawBarsOnLine ******************************************
+/* @funcstatic lindna_DrawBarsOnline ******************************************
 **
 ** draw bars on a line
 **
@@ -1116,13 +1118,13 @@ static void lindna_DrawBracketsOnLine(float xDraw, float yDraw, float Height,
 ** @@
 ******************************************************************************/
 
-static void lindna_DrawBarsOnLine(float xDraw, float yDraw, float Height)
+static void lindna_DrawBarsOnline(float xDraw, float yDraw, float Height)
 {
     float middle;
 
     middle = (float)1.0*Height/(float)2.;
 
-    ajGraphDrawLine(xDraw, yDraw-middle, xDraw, yDraw+middle);
+    ajGraphicsDrawposLine(xDraw, yDraw-middle, xDraw, yDraw+middle);
 
     return;
 }
@@ -1160,11 +1162,13 @@ static void lindna_HorTextPile(float x, float y, const AjPStr Name,
 	    token = ajStrParseC(Name, ";");
 	else
 	    token = ajStrParseC(NULL, ";");
-	stringLength = ajGraphTextLength(0, 0, 1, 0, ajStrGetPtr(token));
-	stringHeight = ajGraphTextHeight(0, 0, 1, 0);
+	stringLength = ajGraphicsCalcTextlengthS(token);
+	stringHeight = ajGraphicsCalcTextheight();
 	yupper = totalHeight+stringHeight;
-	ajGraphDrawTextOnLine(x, (totalHeight+yupper)/2, x+stringLength,
-			      (totalHeight+yupper)/2, ajStrGetPtr(token), 0.5);
+	ajGraphicsDrawposTextAtlineJustify(x, (totalHeight+yupper)/2,
+                                           x+stringLength,
+                                           (totalHeight+yupper)/2,
+                                           ajStrGetPtr(token), 0.5);
 	totalHeight+=(stringHeight+postext);
     }
 
@@ -1194,7 +1198,7 @@ static float lindna_HorTextPileHeight(float postext, ajint NumNames)
     totalHeight = 0.0;
     for(i=0; i<NumNames; i++)
     {
-	stringHeight = ajGraphTextHeight(0, 0, 1, 0);
+	stringHeight = ajGraphicsCalcTextheight();
 	totalHeight+=(stringHeight+postext);
     }
 
@@ -1232,10 +1236,11 @@ static void lindna_VerTextPile(float x, float y, const AjPStr Name,
 	    token = ajStrParseC(Name, ";");
 	else
 	    token = ajStrParseC(NULL, ";");
-	stringLength = ajGraphTextLength(0, 0, 0, 1, ajStrGetPtr(token));
-	ajGraphDrawTextOnLine(x, y+totalLength, x,
-			      y+stringLength+totalLength, ajStrGetPtr(token),
-			      0.0);
+	stringLength = ajGraphicsCalcTextlengthS(token);
+	ajGraphicsDrawposTextAtlineJustify(x, y+totalLength, x,
+                                           y+stringLength+totalLength,
+                                           ajStrGetPtr(token),
+                                           0.0);
 	totalLength+=(stringLength+postext);
     }
 
@@ -1271,7 +1276,7 @@ static float lindna_VerTextPileHeight(const AjPStr Name, float postext,
 	    token = ajStrParseC(Name, ";");
 	else
 	    token = ajStrParseC(NULL, ";");
-	stringLength = ajGraphTextLength(0, 0, 0, 1, ajStrGetPtr(token));
+	stringLength = ajGraphicsCalcTextlengthS(token);
 	totalLength+=(stringLength+postext);
     }
 
@@ -1301,22 +1306,23 @@ static void lindna_VerTextSeq(float x, float y, const AjPStr Name,
     const AjPStr token;
     ajint i;
 
-    stringHeight = ajGraphTextHeight(0, 0, 0, 1)+postext;
+    stringHeight = ajGraphicsCalcTextheight()+postext;
     for(i=0; i<NumNames; i++)
     {
 	if(i==0)
 	    token = ajStrParseC(Name, ";");
 	else
 	    token = ajStrParseC(NULL, ";");
-	ajGraphDrawTextOnLine(x-(float)1.0*NumNames*stringHeight/(float)2.+
-			      (float)1.0*
-			      stringHeight/(float)2.+(float)1.0*i*stringHeight,
-			      y+postext, x-(float)1.0*NumNames*
-			      stringHeight/(float)2.+(float)1.0*
-			      stringHeight/(float)2.+(float)1.0*i*stringHeight,
-			      y+postext+stringHeight,
-			      ajStrGetPtr(token),
-			      (float)0.0);
+	ajGraphicsDrawposTextAtlineJustify(
+            x-(float)1.0*NumNames*stringHeight/(float)2.+
+            (float)1.0*
+            stringHeight/(float)2.+(float)1.0*i*stringHeight,
+            y+postext, x-(float)1.0*NumNames*
+            stringHeight/(float)2.+(float)1.0*
+            stringHeight/(float)2.+(float)1.0*i*stringHeight,
+            y+postext+stringHeight,
+            ajStrGetPtr(token),
+            (float)0.0);
     }
 
     return;
@@ -1352,7 +1358,7 @@ static float lindna_VerTextSeqHeightMax(const AjPStr Name, float postext,
 	    token = ajStrParseC(Name, ";");
 	else
 	    token = ajStrParseC(NULL, ";");
-	stringLength = ajGraphTextLength(0, 0, 0, 1, ajStrGetPtr(token));
+	stringLength = ajGraphicsCalcTextlengthS(token);
 	if(stringLength>maxLength)
 	    maxLength = stringLength;
     }
@@ -1566,8 +1572,9 @@ static float lindna_TextGroup(float Margin, float TextHeight, float TextLength,
     float minsize = 100.0;
     const AjPStr token;
 
-    charsize = ajGraphFitTextOnLine(0, 0, Margin-10, 0, ajStrGetPtr(GroupName),
-				    TextHeight);
+    charsize = ajGraphicsCalcCharsize(0, 0, Margin-10, 0,
+                                      ajStrGetPtr(GroupName),
+                                      TextHeight);
     if(charsize < minsize)
 	minsize = charsize;
 
@@ -1581,11 +1588,13 @@ static float lindna_TextGroup(float Margin, float TextHeight, float TextLength,
 		token = ajStrParseC(NULL, ";");
 
 	    if(TextOri[i]=='H')
-		charsize = ajGraphFitTextOnLine(0, 0, TextLength, 0,
-						ajStrGetPtr(token), TextHeight);
+		charsize = ajGraphicsCalcCharsize(0, 0, TextLength, 0,
+                                                  ajStrGetPtr(token),
+                                                  TextHeight);
 	    else
-		charsize = ajGraphFitTextOnLine(0, 0, 0, TextLength,
-						ajStrGetPtr(token), TextHeight);
+		charsize = ajGraphicsCalcCharsize(0, 0, 0, TextLength,
+                                                  ajStrGetPtr(token),
+                                                  TextHeight);
 	    if(charsize < minsize)
 		minsize = charsize;
 	}
@@ -1732,8 +1741,7 @@ static ajint lindna_OverlapTextGroup(AjPStr const *Name, AjPStr const *Style,
 	    if(TextOri[i]=='H')
 	    {
 		token = ajStrParseC(Name[i], ";");
-		stringLength = ajGraphTextLength(0, 0, 1, 0,
-						 ajStrGetPtr(token));
+		stringLength = ajGraphicsCalcTextlengthS(token);
 		lindnaFromText[i] = From[i]-stringLength/2;
 		lindnaToText[i]   = From[i]+stringLength/2;
 	    }
@@ -1749,8 +1757,7 @@ static ajint lindna_OverlapTextGroup(AjPStr const *Name, AjPStr const *Style,
 	    if(TextOri[i]=='H')
 	    {
 		token = ajStrParseC(Name[i], ";");
-		stringLength = ajGraphTextLength(0, 0, 1, 0,
-						 ajStrGetPtr(token));
+		stringLength = ajGraphicsCalcTextlengthS(token);
 		lindnaFromText[i] = (To[i]+From[i])/2-stringLength/2;
 		lindnaToText[i]   = (To[i]+From[i])/2+stringLength/2;
 	    }
@@ -1766,8 +1773,7 @@ static ajint lindna_OverlapTextGroup(AjPStr const *Name, AjPStr const *Style,
 	    if(TextOri[i]=='H')
 	    {
 		token = ajStrParseC(Name[i], ";");
-		stringLength = ajGraphTextLength(0, 0, 1, 0,
-						 ajStrGetPtr(token));
+		stringLength = ajGraphicsCalcTextlengthS(token);
 		lindnaFromText[i] = (To[i]+From[i])/2-stringLength/2;
 		lindnaToText[i]   = (To[i]+From[i])/2+stringLength/2;
 	    }
@@ -1898,10 +1904,9 @@ static void lindna_DrawGroup(float xDraw, float yDraw, float Border,
 	AJCRESIZE(lindnaInter, lindnaMaxinter);
     }
 
-    /*ajGraphSetBackgroundWhite();*/
-    ajGraphSetFore(1);
-    ajGraphDrawTextOnLine(10, yDraw, xDraw-Border, yDraw,
-			  ajStrGetPtr(GroupName), 0.0);
+    ajGraphicsSetFgcolour(1);
+    ajGraphicsDrawposTextAtlineJustify(10, yDraw, xDraw-Border, yDraw,
+                                       ajStrGetPtr(GroupName), 0.0);
 
     /* draw all labels */
     for(j=0, i=0; i<NumLabels; i++)
@@ -1912,7 +1917,7 @@ static void lindna_DrawGroup(float xDraw, float yDraw, float Border,
 			     postext, TextOri[i],
 			     NumNames[i], Adjust[i], Colour[i]);
 	    if(InterTicks)
-		ajGraphDrawLine(xDraw, yDraw, xDraw+DrawLength, yDraw);
+		ajGraphicsDrawposLine(xDraw, yDraw, xDraw+DrawLength, yDraw);
 	}
 
 	if(ajStrMatchCaseC(Style[i], "Block"))
