@@ -31,6 +31,7 @@ import javax.swing.event.*;
 
 import org.emboss.jemboss.programs.*;
 import org.emboss.jemboss.soap.*;
+import org.emboss.jemboss.Jemboss;
 import org.emboss.jemboss.JembossParams;
 
 /**
@@ -110,7 +111,7 @@ public class ShowSavedResults extends JFrame
   public ShowSavedResults(final JembossParams mysettings, final JFrame f)
   {
 
-    this("Saved Results on Server");
+    this("Saved results list"+(Jemboss.withSoap ? " on server":""));
      
     Dimension d = new Dimension(270,270);
     ss.setPreferredSize(d);
@@ -281,8 +282,13 @@ public class ShowSavedResults extends JFrame
 	    {
 	      setCursor(cbusy);
 	      ResultList thisres = new ResultList(mysettings,
-                                   sel,"show_saved_results"); 
-              new ShowResultSet(thisres.hash(),sel,mysettings);
+                                   sel,"show_saved_results");
+	      if(thisres.hash().size()==0)
+	          JOptionPane.showMessageDialog(sp,
+              "This application launch '"+sel+
+              "' didn't produce any result files.");
+	      else
+	      new ShowResultSet(thisres.hash(),sel,mysettings);
 	      setCursor(cdone);
 	    } 
             catch (JembossSoapException eae)
@@ -385,7 +391,7 @@ public class ShowSavedResults extends JFrame
 	      {
 	        setCursor(cbusy); 
                 selList = convertToOriginal(selList);
-	        ResultList thisres = new ResultList(mysettings,selList,
+	        new ResultList(mysettings,selList,
                                          "delete_saved_results"); 
 	        setCursor(cdone);
 	       
@@ -619,7 +625,7 @@ public class ShowSavedResults extends JFrame
             {
 	      setCursor(cbusy);
               selList = convertToOriginal(selList);
-	      ResultList thisres = new ResultList(mysettings,selList,
+	      new ResultList(mysettings,selList,
                                              "delete_saved_results");
 	      setCursor(cdone);
 
@@ -722,7 +728,7 @@ public class ShowSavedResults extends JFrame
   */
   public static String convertToPretty(String sorig)
   {
-    int index = sorig.indexOf('_');
+//    int index = sorig.indexOf('_');
 //  if(index > -1)
 //    sorig = sorig.substring(0,index) + "\t" +
 //            sorig.substring(index+1);
