@@ -24,6 +24,12 @@
 #define KWLIMIT 12
 
 
+static AjPStr embindexLine      = NULL;
+static AjPStr embindexToken     = NULL;
+static AjPStr embindexTstr      = NULL;
+static AjPStr embindexPrefix    = NULL;
+static AjPStr embindexFormat    = NULL;
+static AjPStrTok embindexHandle = NULL;
 
 
 static AjPFile btreeCreateFile(const AjPStr idirectory, const AjPStr dbname,
@@ -51,20 +57,17 @@ void embBtreeEmblKW(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    line  = ajStrNew();
-    token = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(kwline)[5]);
+    ajStrAssignSubS(&line, kwline, 5, -1);
 
-    handle = ajStrTokenNewC(line,"\n;");
+    handle = ajStrTokenNewC(line,"\n\r;");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
-	    str = ajStrNew();
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -75,8 +78,10 @@ void embBtreeEmblKW(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(kwlist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -109,21 +114,18 @@ void embBtreeEmblTX(const AjPStr txline, AjPList txlist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    line  = ajStrNew();
-    token = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(txline)[5]);
+    ajStrAssignSubS(&line, txline, 5, -1);
 
-    handle = ajStrTokenNewC(line,"\n;()");
+    handle = ajStrTokenNewC(line,"\n\r;()");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimEndC(&token," ");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
-	    str = ajStrNew();
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -134,8 +136,10 @@ void embBtreeEmblTX(const AjPStr txline, AjPList txlist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(txlist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -162,77 +166,65 @@ void embBtreeEmblTX(const AjPStr txline, AjPList txlist, ajuint maxlen)
 
 void embBtreeEmblAC(const AjPStr acline, AjPList aclist)
 {
-    AjPStr line      = NULL;
-    AjPStrTok handle = NULL;
-    AjPStr token     = NULL;
-    AjPStr str       = NULL;
-    AjPStr tstr      = NULL;
-    AjPStr prefix    = NULL;
-    AjPStr format    = NULL;
     char *p          = NULL;
     char *q          = NULL;
     ajuint lo = 0;
     ajuint hi = 0;
     ajuint field = 0;
     ajuint i;
+    AjPStr str = NULL;
     
-    line   = ajStrNew();
-    token  = ajStrNew();
-    tstr   = ajStrNew();
-    prefix = ajStrNew();
-    format = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(acline)[5]);
+    ajStrAssignSubS(&embindexLine, acline, 5, -1);
 
-    handle = ajStrTokenNewC(line,"\n;");
+    ajStrTokenAssignC(&embindexHandle,embindexLine,"\n\r;");
 
-    while(ajStrTokenNextParse(&handle,&token))
+    while(ajStrTokenNextParse(&embindexHandle,&embindexToken))
     {
-	ajStrTrimWhite(&token);
-	if((p=strchr(MAJSTRGETPTR(token),(int)'-')))
+	ajStrTrimWhite(&embindexToken);
+
+	if((p=strchr(MAJSTRGETPTR(embindexToken),(int)'-')))
 	{
 	    q = p;
+
 	    while(isdigit((int)*(--q)));
+
 	    ++q;
-	    ajStrAssignSubC(&tstr,q,0,(ajuint)(p-q-1));
-	    ajStrToUint(tstr,&lo);
+	    ajStrAssignSubC(&embindexTstr,q,0,(ajuint)(p-q-1));
+	    ajStrToUint(embindexTstr,&lo);
 	    field = (ajuint) (p-q);
-	    ajFmtPrintS(&format,"%%S%%0%uu",field);
+	    ajFmtPrintS(&embindexFormat,"%%S%%0%uu",field);
 	    
 	    ++p;
 	    q = p;
+
 	    while(!isdigit((int)*q))
 		++q;
+
 	    sscanf(q,"%u",&hi);
-	    ajStrAssignSubC(&prefix,p,0,(ajuint)(q-p-1));
+	    ajStrAssignSubC(&embindexPrefix,p,0,(ajuint)(q-p-1));
 	    
 	    for(i=lo;i<=hi;++i)
 	    {
-		str = ajStrNew();
-		ajFmtPrintS(&str,MAJSTRGETPTR(format),prefix,i);
+		ajFmtPrintS(&str,MAJSTRGETPTR(embindexFormat),
+			    embindexPrefix,i);
 		ajListPush(aclist,(void *)str);
+		str = NULL;
 	    }
 	}
 	else
 	{
-	    str = ajStrNew();
-	    ajStrAssignS(&str,token);
+	    ajStrAssignS(&str,embindexToken);
 	    ajListPush(aclist,(void *)str);
+	    str = NULL;
 	}
     }
 
-    ajStrDel(&tstr);
-    ajStrDel(&prefix);
-    ajStrDel(&format);
-    ajStrDel(&token);
-    ajStrTokenDel(&handle);
-    ajStrDel(&line);
-    
     return;
 }
 
 
 
+
 /* @func embBtreeEmblSV **************************************************
 **
 ** Extract sequence version from an EMBL new format ID line 
@@ -253,30 +245,29 @@ void embBtreeEmblSV(const AjPStr idline, AjPList svlist)
     AjPStr idstr      = NULL;
     AjPStr svstr      = NULL;
     
-    line   = ajStrNew();
-    token  = ajStrNew();
-    idstr   = ajStrNew();
-    svstr   = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(idline)[5]);
+    ajStrAssignSubS(&line, idline, 5, -1);
 
-    handle = ajStrTokenNewC(line," \t\n;");
+    handle = ajStrTokenNewC(line," \t\n\r;");
 
-    str = ajStrNew();
     if(!ajStrTokenNextParse(&handle,&idstr))
 	return;
+
     if(!ajStrTokenNextParse(&handle,&token))
 	return;
+
     if(!ajStrTokenNextParse(&handle,&svstr))
 	return;
 
     if(!ajStrMatchC(token, "SV"))
 	return;
 
+    str = ajStrNewRes(MAJSTRGETLEN(idstr)+MAJSTRGETLEN(svstr)+2);
+
     ajFmtPrintS(&str,"%S.%S", idstr, svstr);
 
     ajListPush(svlist,(void *)str);
-
+    str = NULL;
+    
     ajStrDel(&idstr);
     ajStrDel(&svstr);
     ajStrDel(&token);
@@ -308,20 +299,17 @@ void embBtreeEmblDE(const AjPStr deline, AjPList delist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    line  = ajStrNew();
-    token = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(deline)[5]);
+    ajStrAssignSubS(&line, deline, 5, -1);
 
-    handle = ajStrTokenNewC(line,"\n \t()");
+    handle = ajStrTokenNewC(line,"\n\r \t()");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
-	    str = ajStrNew();
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -332,8 +320,10 @@ void embBtreeEmblDE(const AjPStr deline, AjPList delist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(delist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -373,24 +363,21 @@ void embBtreeGenBankAC(const AjPStr acline, AjPList aclist)
     ajuint hi = 0;
     ajuint field = 0;
     ajuint i;
-    
-    line   = ajStrNew();
-    token  = ajStrNew();
-    tstr   = ajStrNew();
-    prefix = ajStrNew();
-    format = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(acline)[12]);
 
-    handle = ajStrTokenNewC(line,"\n ");
+    ajStrAssignSubS(&line, acline, 12, -1);
+
+    handle = ajStrTokenNewC(line,"\n\r ");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimWhite(&token);
+
 	if((p=strchr(MAJSTRGETPTR(token),(int)'-')))
 	{
 	    q = p;
+
 	    while(isdigit((int)*(--q)));
+
 	    ++q;
 	    ajStrAssignSubC(&tstr,q,0,(ajuint)(p-q-1));
 	    ajStrToUint(tstr,&lo);
@@ -399,23 +386,25 @@ void embBtreeGenBankAC(const AjPStr acline, AjPList aclist)
 	    
 	    ++p;
 	    q = p;
+
 	    while(!isdigit((int)*q))
 		++q;
+
 	    sscanf(q,"%u",&hi);
 	    ajStrAssignSubC(&prefix,p,0,(ajuint)(q-p-1));
 	    
 	    for(i=lo;i<=hi;++i)
 	    {
-		str = ajStrNew();
 		ajFmtPrintS(&str,MAJSTRGETPTR(format),prefix,i);
 		ajListPush(aclist,(void *)str);
+		str = NULL;
 	    }
 	}
 	else
 	{
-	    str = ajStrNew();
 	    ajStrAssignS(&str,token);
 	    ajListPush(aclist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -451,20 +440,17 @@ void embBtreeGenBankKW(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    line  = ajStrNew();
-    token = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(kwline)[8]);
+    ajStrAssignSubS(&line, kwline, 8, -1);
 
-    handle = ajStrTokenNewC(line,"\n;");
+    handle = ajStrTokenNewC(line,"\n\r;");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
-	    str = ajStrNew();
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -475,8 +461,10 @@ void embBtreeGenBankKW(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(kwlist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -509,20 +497,17 @@ void embBtreeGenBankDE(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    line  = ajStrNew();
-    token = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(kwline)[10]);
+    ajStrAssignSubS(&line, kwline, 10, -1);
 
-    handle = ajStrTokenNewC(line,"\n \t()");
+    handle = ajStrTokenNewC(line,"\n\r \t()");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
-	    str = ajStrNew();
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -533,8 +518,10 @@ void embBtreeGenBankDE(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(kwlist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -567,21 +554,18 @@ void embBtreeGenBankTX(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    line  = ajStrNew();
-    token = ajStrNew();
-    
-    ajStrAssignC(&line, &MAJSTRGETPTR(kwline)[9]);
+    ajStrAssignSubS(&line, kwline, 9, -1);
 
-    handle = ajStrTokenNewC(line,"\n;()");
+    handle = ajStrTokenNewC(line,"\n\r;()");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimEndC(&token," ");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
-	    str = ajStrNew();
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -592,8 +576,10 @@ void embBtreeGenBankTX(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(kwlist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -625,17 +611,17 @@ void embBtreeFastaDE(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
     AjPStr token     = NULL;
     AjPStr str       = NULL;
     
-    token = ajStrNew();
-    
-    handle = ajStrTokenNewC(kwline,"\n ");
+    handle = ajStrTokenNewC(kwline,"\n\r ");
 
     while(ajStrTokenNextParse(&handle,&token))
     {
 	ajStrTrimEndC(&token,".");
 	ajStrTrimWhite(&token);
+
 	if(ajStrGetLen(token))
 	{
 	    str = ajStrNew();
+
 	    if(maxlen)
 	    {
 		if(ajStrGetLen(token) > maxlen)
@@ -646,8 +632,61 @@ void embBtreeFastaDE(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
 	    }
 	    else
 		ajStrAssignS(&str,token);
+
 	    ajStrFmtLower(&str);
 	    ajListPush(kwlist,(void *)str);
+	    str = NULL;
+	}
+    }
+
+    ajStrDel(&token);
+    ajStrTokenDel(&handle);
+    
+    return;
+}
+
+
+
+
+/* @func embBtreeFastaSV **************************************************
+**
+** Extract sequence version keywords from a Fasta description
+**
+** @param [r] kwline[const AjPStr] sequence version or GI string
+** @param [w] kwlist [AjPList] list of sequence versions
+** @param [r] maxlen [ajuint] max sequence version length
+**
+** @return [void]
+** @@
+******************************************************************************/
+
+void embBtreeFastaSV(const AjPStr kwline, AjPList kwlist, ajuint maxlen)
+{
+    AjPStrTok handle = NULL;
+    AjPStr token     = NULL;
+    AjPStr str       = NULL;
+
+    handle = ajStrTokenNewC(kwline,"\n ");
+
+    while(ajStrTokenNextParse(&handle,&token))
+    {
+	ajStrTrimEndC(&token,".");
+	ajStrTrimWhite(&token);
+
+	if(ajStrGetLen(token))
+	{
+	    if(maxlen)
+	    {
+		if(ajStrGetLen(token) > maxlen)
+                    ajStrAssignSubS(&str,token,0,maxlen-1);
+		else
+		    ajStrAssignS(&str,token);
+            }
+	    else
+		ajStrAssignS(&str,token);
+	    ajStrFmtLower(&str);
+	    ajListPush(kwlist,(void *)str);
+	    str = NULL;
 	}
     }
 
@@ -687,16 +726,17 @@ ajuint embBtreeReadDir(AjPStr **filelist, const AjPStr fdirectory,
     /* ajDebug("In ajBtreeReadDir\n"); */
 
     lfiles = ajListNew();
-    nfiles = ajFileScan(fdirectory,files,&lfiles,ajFalse,ajFalse,NULL,NULL,
-			ajFalse,NULL);
+    nfiles = ajFilelistAddPathWild(lfiles, fdirectory, files);
 
     nremove = ajArrCommaList(exclude,&removelist);
     
     for(i=0;i<nfiles;++i)
     {
 	ajListPop(lfiles,(void **)&file);
-	ajFileNameTrim(&file);
+	ajFilenameTrimPath(&file);
+
 	for(j=0;j<nremove && ! ajStrMatchWildS(file,removelist[j]);++j);
+
 	if(j == nremove)
 	    ajListPushAppend(lfiles,(void *)file);
     }
@@ -706,6 +746,7 @@ ajuint embBtreeReadDir(AjPStr **filelist, const AjPStr fdirectory,
 
     for(i=0; i<nremove;++i)
 	ajStrDel(&removelist[i]);
+
     AJFREE(removelist);
 
     return nfiles;
@@ -738,9 +779,10 @@ static AjPFile btreeCreateFile(const AjPStr idirectory, const AjPStr dbname,
 
     ajFmtPrintS(&filename,"%S%s%S%s",idirectory,SLASH_STRING,dbname,add);
     
-    fp =  ajFileNewOut(filename);
+    fp =  ajFileNewOutNameS(filename);
 
     ajStrDel(&filename);
+
     return fp;
 }
 
@@ -821,10 +863,12 @@ void embBtreeEntryDel(EmbPBtreeEntry* thys)
 
     while(ajListPop(pthis->files,(void **)&tmpstr))
 	ajStrDel(&tmpstr);
+
     ajListFree(&pthis->files);
 
     while(ajListPop(pthis->reffiles,(void **)&tmpstr))
 	ajStrDel(&tmpstr);
+
     ajListFree(&pthis->reffiles);
 
     ajStrDel(&pthis->id);
@@ -860,6 +904,7 @@ ajuint embBtreeSetFields(EmbPBtreeEntry entry, AjPStr const *fields)
 
 
     nfields = 0;
+
     while(fields[nfields])
     {
 	if(ajStrMatchCaseC(fields[nfields], "id"))
@@ -956,17 +1001,19 @@ ajuint embBtreeGetFiles(EmbPBtreeEntry entry, const AjPStr fdirectory,
     
     /* ajDebug("In embBtreeGetFiles\n"); */
 
-    nfiles = ajFileScan(fdirectory,files,&entry->files,ajFalse,ajFalse,NULL,
-			NULL,ajFalse,NULL);
+    nfiles = ajFilelistAddPathWild(entry->files, fdirectory,files);
 
     nremove = ajArrCommaList(exclude,&removelist);
 
     count = 0;
+
     for(i=0;i<nfiles;++i)
     {
 	ajListPop(entry->files,(void **)&file);
-	ajFileNameTrim(&file);
+	ajFilenameTrimPath(&file);
+
 	for(j=0;j<nremove && !ajStrMatchWildS(file,removelist[j]);++j);
+
 	if(j == nremove)
 	{
 	    ajListPushAppend(entry->files,(void *)file);
@@ -980,6 +1027,7 @@ ajuint embBtreeGetFiles(EmbPBtreeEntry entry, const AjPStr fdirectory,
 
     for(i=0; i<nremove;++i)
 	ajStrDel(&removelist[i]);
+
     AJFREE(removelist);
 
     return count;
@@ -1017,14 +1065,15 @@ AjBool embBtreeWriteEntryFile(const EmbPBtreeEntry entry)
     ajFmtPrintF(entfile,"# Date:    %S\n",entry->date);
 
     do_ref = (ajListGetLength(entry->reffiles)) ? ajTrue : ajFalse;
+
     if(!do_ref)
 	ajFmtPrintF(entfile,"Single");
     else
 	ajFmtPrintF(entfile,"Dual");
+
     ajFmtPrintF(entfile," filename database\n");
     
     for(i=0;i<entry->nfiles;++i)
-    {
 	if(!do_ref)
 	{
 	    ajListPop(entry->files,(void **)&tmpstr);
@@ -1039,8 +1088,6 @@ AjBool embBtreeWriteEntryFile(const EmbPBtreeEntry entry)
 	    ajListPushAppend(entry->files,(void *)tmpstr);
 	    ajListPushAppend(entry->reffiles,(void *)refstr);
 	}
-	
-    }
 
     ajFileClose(&entfile);
     
@@ -1065,17 +1112,54 @@ void embBtreeGetRsInfo(EmbPBtreeEntry entry)
     const char *resource;
     AjPStr value = NULL;
     ajuint  n = 0;
-    
+
     value = ajStrNew();
     
 
     resource = ajStrGetPtr(entry->dbrs);
+
     if(!ajNamRsAttrValueC(resource,"type",&value))
 	ajFatal("Missing resource entry (%S) for indexing",entry->dbrs);
+
     if(!ajStrMatchCaseC(value,"Index"))
 	ajFatal("Incorrect 'type' field for resource (%S)",entry->dbrs);
 
 
+    if(!ajNamGetValueC("CACHESIZE",&value))
+    {
+	entry->cachesize = BTREE_DEF_CACHESIZE;
+	ajUser("CACHESIZE defaults to %d", entry->cachesize);
+    }
+    else
+    {
+	if(ajStrToUint(value,&n))
+	{
+	    entry->cachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for environment variable 'CACHESIZE'");
+	    entry->cachesize = BTREE_DEF_CACHESIZE;
+	}
+    }
+
+    if(!ajNamGetValueC("PAGESIZE",&value))
+    {
+	entry->pagesize = BTREE_DEF_PAGESIZE;
+	ajUser("PAGESIZE defaults to %d", entry->pagesize);
+    }
+    else
+    {
+	if(ajStrToUint(value,&n))
+	{
+	    entry->pagesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for environment variable 'PAGESIZE'");
+	    entry->pagesize = BTREE_DEF_PAGESIZE;
+	}
+    }
 
     if(!ajNamRsAttrValueC(resource,"idlen",&value))
 	entry->idlen = BTREE_DEF_IDLEN;
@@ -1155,64 +1239,263 @@ void embBtreeGetRsInfo(EmbPBtreeEntry entry)
 	}
     }
 
-    if(!ajNamGetValueC("CACHESIZE",&value))
-	entry->cachesize = BTREE_DEF_CACHESIZE;
+    if(!ajNamRsAttrValueC(resource,"idpagesize",&value))
+	entry->idpagesize = entry->pagesize;
     else
     {
-	if(ajStrToUint(value,&n))
-	    entry->cachesize = n;
+        if(ajStrToUint(value,&n))
+	{
+	    entry->idpagesize = n;
+	}
 	else
 	{
-	    ajErr("Bad value for environment variable 'CACHESIZE'");
-	    entry->cachesize = BTREE_DEF_CACHESIZE;
+	    ajErr("Bad value for index resource 'idpagesize'");
+	    entry->idpagesize = entry->pagesize;
 	}
     }
-
-    if(!ajNamGetValueC("PAGESIZE",&value))
-	entry->pagesize = BTREE_DEF_PAGESIZE;
+        
+    if(!ajNamRsAttrValueC(resource,"accpagesize",&value))
+	entry->acpagesize = entry->pagesize;
     else
     {
-	if(ajStrToUint(value,&n))
-	    entry->pagesize = n;
+        if(ajStrToUint(value,&n))
+	{
+	    entry->acpagesize = n;
+	}
 	else
 	{
-	    ajErr("Bad value for environment variable 'PAGESIZE'");
-	    entry->pagesize = BTREE_DEF_PAGESIZE;
+	    ajErr("Bad value for index resource 'accpagesize'");
+	    entry->acpagesize = entry->pagesize;
 	}
     }
+        
+    if(!ajNamRsAttrValueC(resource,"svpagesize",&value))
+	entry->svpagesize = entry->pagesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->svpagesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'svpagesize'");
+	    entry->svpagesize = entry->pagesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"keypagesize",&value))
+	entry->kwpagesize = entry->pagesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->kwpagesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'keypagesize'");
+	    entry->kwpagesize = entry->pagesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"despagesize",&value))
+	entry->depagesize = entry->pagesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->depagesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'despagesize'");
+	    entry->depagesize = entry->pagesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"orgpagesize",&value))
+	entry->txpagesize = entry->pagesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->txpagesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'orgpagesize'");
+	    entry->txpagesize = entry->pagesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"idcachesize",&value))
+	entry->idcachesize = entry->cachesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->idcachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'idcachesize'");
+	    entry->idcachesize = entry->cachesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"acccachesize",&value))
+	entry->accachesize = entry->cachesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->accachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'acccachesize'");
+	    entry->accachesize = entry->cachesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"svcachesize",&value))
+	entry->svcachesize = entry->cachesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->svcachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'svcachesize'");
+	    entry->svcachesize = entry->cachesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"keycachesize",&value))
+	entry->kwcachesize = entry->cachesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->kwcachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'keycachesize'");
+	    entry->kwcachesize = entry->cachesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"descachesize",&value))
+	entry->decachesize = entry->cachesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->decachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'descachesize'");
+	    entry->decachesize = entry->cachesize;
+	}
+    }
+        
+    if(!ajNamRsAttrValueC(resource,"orgcachesize",&value))
+	entry->txcachesize = entry->cachesize;
+    else
+    {
+        if(ajStrToUint(value,&n))
+	{
+	    entry->txcachesize = n;
+	}
+	else
+	{
+	    ajErr("Bad value for index resource 'orgcachesize'");
+	    entry->txcachesize = entry->cachesize;
+	}
+    }
+        
+    entry->idorder = (entry->idpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->idlen + 1) + BT_IDKEYEXTRA);
 
-    
-    entry->idorder = (entry->pagesize - 60) / ((entry->idlen + 1) + 12);
-    entry->idfill  = (entry->pagesize - 16) / (entry->idlen + 28);
-    entry->acorder = (entry->pagesize - 60) / ((entry->aclen + 1) + 12);
-    entry->acfill  = (entry->pagesize - 16) / (entry->aclen + 28);
-    entry->svorder = (entry->pagesize - 60) / ((entry->svlen + 1) + 12);
-    entry->svfill  = (entry->pagesize - 16) / (entry->svlen + 28);
+    entry->idfill  = (entry->idpagesize - BT_BUCKPREAMBLE) /
+        ((entry->idlen + 1) + BT_KEYLENENTRY + BT_DDOFFROFF);
 
-    entry->kworder = (entry->pagesize - 60) / ((entry->kwlen + 1) + 12);
-    entry->kwfill  = (entry->pagesize - 16) / (entry->kwlen + 28);
-    entry->deorder = (entry->pagesize - 60) / ((entry->delen + 1) + 12);
-    entry->defill  = (entry->pagesize - 16) / (entry->delen + 28);
-    entry->txorder = (entry->pagesize - 60) / ((entry->txlen + 1) + 12);
-    entry->txfill  = (entry->pagesize - 16) / (entry->txlen + 28);
+    entry->acorder = (entry->acpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->aclen + 1) + BT_IDKEYEXTRA);
 
-    entry->kwsecorder = (entry->pagesize - 60) / ((entry->idlen + 1) + 12);
-    entry->desecorder = (entry->pagesize - 60) / ((entry->idlen + 1) + 12);
-    entry->txsecorder = (entry->pagesize - 60) / ((entry->idlen + 1) + 12);
+    entry->acfill  = (entry->acpagesize - BT_BUCKPREAMBLE) /
+        ((entry->aclen + 1) + BT_KEYLENENTRY + BT_DDOFFROFF);
 
-    entry->kwsecfill  = (entry->pagesize - 16) / (entry->idlen + 4);
-    entry->desecfill  = (entry->pagesize - 16) / (entry->idlen + 4);
-    entry->txsecfill  = (entry->pagesize - 16) / (entry->idlen + 4);
+    entry->svorder = (entry->svpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->svlen + 1) + BT_IDKEYEXTRA);
 
-    entry->idsecorder = (entry->pagesize - 60) / 24;
-    entry->idsecfill  = (entry->pagesize - 60) / 20;
+    entry->svfill  = (entry->svpagesize - BT_BUCKPREAMBLE) /
+        ((entry->svlen + 1) + BT_KEYLENENTRY + BT_DDOFFROFF);
 
-    entry->acsecorder = (entry->pagesize - 60) / 24;
-    entry->acsecfill  = (entry->pagesize - 60) / 20;
+    entry->kworder = (entry->kwpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->kwlen + 1) + BT_IDKEYEXTRA);
+
+    entry->kwfill  = (entry->kwpagesize - BT_BUCKPREAMBLE) /
+        ((entry->kwlen + 1) + BT_KEYLENENTRY + BT_DDOFFROFF);
+
+    entry->deorder = (entry->depagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->delen + 1) + BT_IDKEYEXTRA);
+
+    entry->defill  = (entry->depagesize - BT_BUCKPREAMBLE) /
+        ((entry->delen + 1) + BT_KEYLENENTRY + BT_DDOFFROFF);
+
+    entry->txorder = (entry->txpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->txlen + 1) + BT_IDKEYEXTRA);
+
+    entry->txfill  = (entry->txpagesize - BT_BUCKPREAMBLE) /
+        ((entry->txlen + 1) + BT_KEYLENENTRY + BT_DDOFFROFF);
+
+ 
+    entry->idsecorder = (entry->idpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        (BT_OFFKEYLEN + BT_IDKEYEXTRA);
+
+    entry->acsecorder = (entry->acpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        (BT_OFFKEYLEN + BT_IDKEYEXTRA);
+
+    entry->svsecorder = (entry->svpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        (BT_OFFKEYLEN + BT_IDKEYEXTRA);
+
+ 
+    entry->idsecfill  = (entry->idpagesize - BT_BUCKPREAMBLE) /
+        BT_DOFFROFF;
+
+    entry->acsecfill  = (entry->acpagesize - BT_BUCKPREAMBLE) /
+        BT_DOFFROFF;
+
+    entry->svsecfill  = (entry->svpagesize - BT_BUCKPREAMBLE) /
+        BT_DOFFROFF;
+
+
+    /*
+     *  The secondary tree keys are the IDs of the entries containing
+     *  the keywords
+     */
+
+    entry->kwsecorder = (entry->kwpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->idlen + 1) + BT_IDKEYEXTRA);
+    entry->desecorder = (entry->depagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->idlen + 1) + BT_IDKEYEXTRA);
+    entry->txsecorder = (entry->txpagesize - (BT_NODEPREAMBLE + BT_PTRLEN)) /
+        ((entry->idlen + 1) + BT_IDKEYEXTRA);
+
+
+    entry->kwsecfill  = (entry->kwpagesize - BT_BUCKPREAMBLE) /
+        ((entry->idlen + 1) + BT_KEYLENENTRY);
+    entry->desecfill  = (entry->depagesize - BT_BUCKPREAMBLE) /
+        ((entry->idlen + 1) + BT_KEYLENENTRY);
+    entry->txsecfill  = (entry->txpagesize - BT_BUCKPREAMBLE) /
+        ((entry->idlen + 1) + BT_KEYLENENTRY);
 
-    entry->svsecorder = (entry->pagesize - 60) / 24;
-    entry->svsecfill  = (entry->pagesize - 60) / 20;
-    
     ajStrDel(&value);
 
     return;
@@ -1246,12 +1529,12 @@ AjBool embBtreeOpenCaches(EmbPBtreeEntry entry)
     if(entry->do_id)
     {
 	entry->idcache = ajBtreeSecCacheNewC(basenam,ID_EXTENSION,idir,"w+",
-					     entry->pagesize, entry->idorder,
+					     entry->idpagesize, entry->idorder,
 					     entry->idfill, level,
-					     entry->cachesize,
+					     entry->idcachesize,
 					     entry->idsecorder, slevel,
 					     entry->idsecfill, count,
-					     entry->kwlen);
+					     entry->idlen);
 	if(!entry->idcache)
 	    ajFatal("Cannot open ID index");
 	
@@ -1261,13 +1544,13 @@ AjBool embBtreeOpenCaches(EmbPBtreeEntry entry)
     if(entry->do_accession)
     {
 	entry->accache = ajBtreeSecCacheNewC(basenam,AC_EXTENSION,idir,"w+",
-					     entry->pagesize,
+					     entry->acpagesize,
 					     entry->acorder, entry->acfill,
 					     level,
-					     entry->cachesize,
+					     entry->accachesize,
 					     entry->acsecorder, slevel,
 					     entry->acsecfill, count,
-					     entry->kwlen);
+					     entry->aclen);
 	if(!entry->accache)
 	    ajFatal("Cannot open ACC index");
 
@@ -1277,12 +1560,12 @@ AjBool embBtreeOpenCaches(EmbPBtreeEntry entry)
     if(entry->do_sv)
     {
 	entry->svcache = ajBtreeSecCacheNewC(basenam,SV_EXTENSION,idir,"w+",
-					     entry->pagesize, entry->svorder,
+					     entry->svpagesize, entry->svorder,
 					     entry->svfill, level,
-					     entry->cachesize,
+					     entry->svcachesize,
 					     entry->svsecorder, slevel,
 					     entry->svsecfill, count,
-					     entry->kwlen);
+					     entry->svlen);
 	if(!entry->svcache)
 	    ajFatal("Cannot open SV index");
 
@@ -1294,10 +1577,10 @@ AjBool embBtreeOpenCaches(EmbPBtreeEntry entry)
     if(entry->do_keyword)
     {
 	entry->kwcache = ajBtreeSecCacheNewC(basenam,KW_EXTENSION,idir,"w+",
-					     entry->pagesize,
+					     entry->kwpagesize,
 					     entry->kworder, entry->kwfill,
 					     level,
-					     entry->cachesize,
+					     entry->kwcachesize,
 					     entry->kwsecorder, slevel,
 					     entry->kwsecfill, count,
 					     entry->kwlen);
@@ -1311,10 +1594,10 @@ AjBool embBtreeOpenCaches(EmbPBtreeEntry entry)
     if(entry->do_description)
     {
 	entry->decache = ajBtreeSecCacheNewC(basenam,DE_EXTENSION,idir,"w+",
-					     entry->pagesize,
+					     entry->depagesize,
 					     entry->deorder, entry->defill,
 					     level,
-					     entry->cachesize,
+					     entry->decachesize,
 					     entry->desecorder, slevel,
 					     entry->desecfill, count,
 					     entry->delen);
@@ -1328,10 +1611,10 @@ AjBool embBtreeOpenCaches(EmbPBtreeEntry entry)
     if(entry->do_taxonomy)
     {
 	entry->txcache = ajBtreeSecCacheNewC(basenam,TX_EXTENSION,idir,"w+",
-					     entry->pagesize,
+					     entry->txpagesize,
 					     entry->txorder, entry->txfill,
 					     level,
-					     entry->cachesize,
+					     entry->txcachesize,
 					     entry->txsecorder, slevel,
 					     entry->txsecfill, count,
 					     entry->txlen);
@@ -1415,6 +1698,47 @@ AjBool embBtreeCloseCaches(EmbPBtreeEntry entry)
 
 
 
+#if 0
+
+/* @func embBtreeProbeCaches ***********************************************
+**
+** Close index files
+**
+** @param [u] entry [EmbPBtreeEntry] database data
+**
+** @return [AjBool] true on success
+** @@
+******************************************************************************/
+
+AjBool embBtreeProbeCaches(EmbPBtreeEntry entry)
+{
+
+    if(entry->do_id)
+    {
+	ajBtreeProbePriArray(entry->idcache);
+	ajBtreeProbeSecArray(entry->idcache);
+    }
+
+    if(entry->do_accession)
+    {
+	ajBtreeProbePriArray(entry->accache);
+	ajBtreeProbeSecArray(entry->accache);
+    }
+
+    if(entry->do_sv)
+    {
+	ajBtreeProbePriArray(entry->svcache);
+	ajBtreeProbeSecArray(entry->svcache);
+    }
+
+    return ajTrue;
+}
+
+#endif
+
+
+
+
 /* @func embBtreeDumpParameters ***********************************************
 **
 ** Write index parameter files
@@ -1454,3 +1778,25 @@ AjBool embBtreeDumpParameters(EmbPBtreeEntry entry)
 
     return ajTrue;
 }
+
+
+
+
+/* @func embIndexExit **********************************************************
+**
+** Cleanup indexing internals on exit
+**
+** @return [void]
+******************************************************************************/
+
+void embIndexExit(void)
+{
+    ajStrDel(&embindexLine);
+    ajStrDel(&embindexToken);
+    ajStrDel(&embindexTstr);
+    ajStrDel(&embindexPrefix);
+    ajStrDel(&embindexFormat);
+    ajStrTokenDel(&embindexHandle);
+
+    return;
+}
