@@ -44,7 +44,14 @@
 #include <string.h>
 #include <stdlib.h>
 
-#define AJAXDEF "ajaxdll.def"
+#define COREDEF "ajaxdll.def"
+#define PCREDEF "epcredll.def"
+#define EXPATDEF "eexpatdll.def"
+#define ZLIBDEF "ezlibdll.def"
+#define GRAPHICSDEF "ajaxgdll.def"
+#define ENSEMBLDEF "ensembldll.def"
+#define AJAXDBDEF "ajaxdbdll.def"
+#define ACDDEF "acddll.def"
 #define NUCLEUSDEF "nucleusdll.def"
 
 #define TMPFILE  "/tmp/hfuncts_1"
@@ -63,7 +70,18 @@ typedef struct node
 } listnode;
 
 
+/*
+** Exclude specific programs
+*/
 
+static char *exclude_names[]=
+{
+    "dbxreport.c",
+    "dbxstat.c",
+    NULL
+};
+
+    
 
 /*
 ** Specify any programs with special memory reqirements.
@@ -98,12 +116,17 @@ static void copy_data(char *basedir);
 static void copy_doc(char *basedir);
 static void copy_test(char *basedir);
 static void copy_jemboss(char *basedir);
+static void copy_mysql(char *basedir);
 static void copy_redist(char *basedir);
     
 static void create_directories(char *basedir);
+static void make_ajax_header_exports(char *basedir,char *subdir);
 static int header_exports(char *dir, FILE *fp);
 static void extract_funcnames(char *filename, FILE *fout);
-static void write_ajaxexports(char *fn, char *basedir);
+static void write_coreexports(char *fn, char *basedir);
+static void write_genajaxexport(char *fn,char *basedir,char *exportdef,
+                                char *subdir,char *dllname);
+
 static void write_nucleusexports(char *fn,char *basedir);
 static void read_make_check(char *basedir, listnode **head);
 static void add_node(listnode **head, char *progname);
@@ -116,6 +139,13 @@ static void write_projects(char *basedir, char **prognames, char **uids,
 static void sub_text(char *line, char *tline, char *given, char *rep);
 static void zip_up(char *basedir);
 
+static void extract_expat_funcnames(char *filename, FILE *fout);
+static void make_expat_header_exports(char *basedir);
+static void make_zlib_header_exports(char *basedir);
+static void extract_zlib_funcnames(char *filename, FILE *fout);
+
+
+
 
 int main(int argc, char **argv)
 {
@@ -127,7 +157,8 @@ int main(int argc, char **argv)
     listnode *tptr;
     char **uids = NULL;
     char **prognames = NULL;
-    
+    char *vcfiles = NULL;
+
     FILE *fp = NULL;
     
     int len;
@@ -144,7 +175,7 @@ int main(int argc, char **argv)
 	    basedir[len-1] = '\0';
     }
 
-    sprintf(ajaxdir,"%s/emboss/ajax",basedir);
+
 
 
     /* Create Windows build directories as a 'win32' subdir of basedir */
@@ -163,27 +194,45 @@ int main(int argc, char **argv)
     copy_doc(basedir);
     copy_test(basedir);
     copy_jemboss(basedir);
+    copy_mysql(basedir);
     copy_redist(basedir);
 
 
+
+    
     /* Construct exports file (ajaxdll.def) */
-    
-    if(!(fp=fopen(TMPFILE,"w")))
-    {
-	fprintf(stderr,"Cannot open temporary file %s\n",TMPFILE);
-	exit(-1);
-    }
-    
 
-    if(header_exports(ajaxdir,fp) < 0)
-    {
-	fprintf(stderr,"Cannot open directory %s/ajax",basedir);
-	exit(-1);
-    }
-    fclose(fp);
-    
-    write_ajaxexports(TMPFILE,basedir);
 
+    
+    make_ajax_header_exports(basedir,"core");
+    write_coreexports(TMPFILE,basedir);
+
+    make_expat_header_exports(basedir);
+    write_genajaxexport(TMPFILE,basedir,EXPATDEF,"expat","eexpat");
+
+    make_zlib_header_exports(basedir);
+    write_genajaxexport(TMPFILE,basedir,ZLIBDEF,"zlib","ezlib");
+
+
+    make_ajax_header_exports(basedir,"pcre");    
+    write_genajaxexport(TMPFILE,basedir,PCREDEF,"pcre","epcre");
+
+
+    make_ajax_header_exports(basedir,"graphics");
+    write_genajaxexport(TMPFILE,basedir,GRAPHICSDEF,"graphics","ajaxg");
+
+
+    make_ajax_header_exports(basedir,"ensembl");
+    write_genajaxexport(TMPFILE,basedir,ENSEMBLDEF,"ensembl","ensembl");
+
+
+    make_ajax_header_exports(basedir,"ajaxdb");    
+    write_genajaxexport(TMPFILE,basedir,AJAXDBDEF,"ajaxdb","ajaxdb");
+
+
+    make_ajax_header_exports(basedir,"acd");        
+    write_genajaxexport(TMPFILE,basedir,ACDDEF,"acd","acd");
+    
 
     /* Construct exports file (nucleusdll.def) */
 
@@ -265,7 +314,7 @@ static void copy_ajax(char *basedir)
 
     /* First copy ajax .h & .c files */
 
-    sprintf(command,"cp -f %s/emboss/ajax/*.h %s/win32/ajax",basedir,
+    sprintf(command,"cp -f %s/emboss/ajax/pcre/*.h %s/win32/ajax/pcre",basedir,
 	    basedir);
     if(system(command))
     {
@@ -273,7 +322,55 @@ static void copy_ajax(char *basedir)
 	exit(-1);
     }
 
-    sprintf(command,"cp -f %s/emboss/ajax/*.c %s/win32/ajax",basedir,
+    sprintf(command,"cp -f %s/emboss/ajax/pcre/*.c %s/win32/ajax/pcre",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/expat/*.h %s/win32/ajax/expat",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/expat/*.c %s/win32/ajax/expat",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/zlib/*.h %s/win32/ajax/zlib",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/zlib/*.c %s/win32/ajax/zlib",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/core/*.h %s/win32/ajax/core",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/core/*.c %s/win32/ajax/core",basedir,
 	    basedir);
     if(system(command))
     {
@@ -282,8 +379,77 @@ static void copy_ajax(char *basedir)
     }
 
 
+    sprintf(command,"cp -f %s/emboss/ajax/graphics/*.h %s/win32/ajax/graphics",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/graphics/*.c %s/win32/ajax/graphics",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+
+    sprintf(command,"cp -f %s/emboss/ajax/ensembl/*.h %s/win32/ajax/ensembl",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/ensembl/*.c %s/win32/ajax/ensembl",
+            basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+
+    sprintf(command,"cp -f %s/emboss/ajax/ajaxdb/*.h %s/win32/ajax/ajaxdb",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/ajaxdb/*.c %s/win32/ajax/ajaxdb",
+            basedir, basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+
+    sprintf(command,"cp -f %s/emboss/ajax/acd/*.h %s/win32/ajax/acd",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -f %s/emboss/ajax/acd/*.c %s/win32/ajax/acd",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    
+    
     /* Copy extra files required by win32 */
-    sprintf(command,"cp -fR %s/emboss/win32/ajax/* %s/win32/ajax",basedir,
+    sprintf(command,"cp -fR %s/emboss/win32/ajax/* %s/win32/ajax/core",basedir,
 	    basedir);
     if(system(command))
     {
@@ -401,7 +567,71 @@ static void copy_DLLs(char *basedir)
 
     /* Copy ajax project files */
 
-    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/* %s/win32/DLLs/ajax",
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/acd.vcproj "
+            "%s/win32/DLLs/ajax/acd",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/ajaxdb.vcproj "
+            "%s/win32/DLLs/ajax/ajaxdb",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/ajaxg.vcproj "
+            "%s/win32/DLLs/ajax/graphics",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/core.vcproj "
+            "%s/win32/DLLs/ajax/core",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/ensembl.vcproj "
+            "%s/win32/DLLs/ajax/ensembl",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/expat.vcproj "
+            "%s/win32/DLLs/ajax/expat",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/zlib.vcproj "
+            "%s/win32/DLLs/ajax/zlib",
+	    basedir,basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp -fR %s/emboss/win32/DLLs/ajax/pcre.vcproj "
+            "%s/win32/DLLs/ajax/pcre",
 	    basedir,basedir);
     if(system(command))
     {
@@ -522,6 +752,100 @@ static void copy_test(char *basedir)
 
 
 
+static void copy_mysql(char *basedir)
+{
+    char command[MAXNAMLEN];
+
+    sprintf(command,"cp %s/emboss/win32/mysql/Debug/*.dll "
+            "%s/win32/mysql/Debug",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp %s/emboss/win32/mysql/Debug/*.lib "
+            "%s/win32/mysql/Debug",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp %s/emboss/win32/mysql/Debug/*.pdb "
+            "%s/win32/mysql/Debug",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp %s/emboss/win32/mysql/Release/*.dll "
+            "%s/win32/mysql/Release",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+
+    sprintf(command,"cp %s/emboss/win32/mysql/Release/*.lib "
+            "%s/win32/mysql/Release",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+
+    sprintf(command,"cp %s/emboss/win32/mysql/Release/*.pdb "
+            "%s/win32/mysql/Release",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+
+    sprintf(command,"cp %s/emboss/win32/mysql/include/*.h "
+            "%s/win32/mysql/include",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp %s/emboss/win32/mysql/include/*.def "
+            "%s/win32/mysql/include",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    sprintf(command,"cp %s/emboss/win32/mysql/include/mysql/*.h "
+            "%s/win32/mysql/include/mysql",basedir,
+	    basedir);
+    if(system(command))
+    {
+	fprintf(stderr,"Can't execute %s\n",command);
+	exit(-1);
+    }
+
+    return;
+}
+
+
+
+
 static void copy_redist(char *basedir)
 {
     char command[MAXNAMLEN];
@@ -531,10 +855,21 @@ static void copy_redist(char *basedir)
     static char *def2="/root/vc80";
     int len;
     
-    fprintf(stdout,"Redist 90 file directory [%s]: ",def);
+    char vc80[MAXNAMLEN];
+    char vc90[MAXNAMLEN];
+    char *ev = NULL;
+
+
+    if((ev = getenv("vc90files")))
+        strcpy(vc90,ev);
+    else
+        strcpy(vc90,def);
+    
+
+    fprintf(stdout,"Redist 90 file directory [%s]: ",vc90);
     fgets(prompt,MAXNAMLEN,stdin);
     if(*prompt == '\n')
-        sprintf(prompt,"%s",def);
+        sprintf(prompt,"%s",vc90);
 
     len = strlen(prompt);
     if(prompt[len-1] == '\n')
@@ -549,10 +884,16 @@ static void copy_redist(char *basedir)
 	exit(-1);
     }
 
-    fprintf(stdout,"Redist 80 file directory [%s]: ",def2);
+    if((ev = getenv("vc80files")))
+        strcpy(vc80,ev);
+    else
+        strcpy(vc80,def2);
+
+    
+    fprintf(stdout,"Redist 80 file directory [%s]: ",vc80);
     fgets(prompt,MAXNAMLEN,stdin);
     if(*prompt == '\n')
-        sprintf(prompt,"%s",def2);
+        sprintf(prompt,"%s",vc80);
 
     len = strlen(prompt);
     if(prompt[len-1] == '\n')
@@ -610,6 +951,14 @@ static void create_directories(char *basedir)
     {
 	"win32",
 	"win32/ajax",
+        "win32/ajax/pcre",
+        "win32/ajax/expat",
+        "win32/ajax/zlib",
+        "win32/ajax/core",
+        "win32/ajax/graphics",
+        "win32/ajax/ensembl",
+        "win32/ajax/ajaxdb",
+        "win32/ajax/acd",
 	"win32/nucleus",
 	"win32/emboss",
 	"win32/apps",
@@ -623,8 +972,30 @@ static void create_directories(char *basedir)
 	"win32/plplot-inc/lib/Debug",
 	"win32/plplot-inc/lib/Release",
 	"win32/DLLs/ajax",
-	"win32/DLLs/ajax/Debug",
-	"win32/DLLs/ajax/Release",
+	"win32/DLLs/ajax/pcre",
+	"win32/DLLs/ajax/expat",
+	"win32/DLLs/ajax/zlib",
+	"win32/DLLs/ajax/core",
+	"win32/DLLs/ajax/graphics",
+	"win32/DLLs/ajax/ensembl",
+	"win32/DLLs/ajax/ajaxdb",
+	"win32/DLLs/ajax/acd",
+	"win32/DLLs/ajax/core/Debug",
+	"win32/DLLs/ajax/core/Release",
+	"win32/DLLs/ajax/pcre/Debug",
+	"win32/DLLs/ajax/pcre/Release",
+	"win32/DLLs/ajax/expat/Debug",
+	"win32/DLLs/ajax/expat/Release",
+	"win32/DLLs/ajax/zlib/Debug",
+	"win32/DLLs/ajax/zlib/Release",
+	"win32/DLLs/ajax/graphics/Debug",
+	"win32/DLLs/ajax/graphics/Release",
+	"win32/DLLs/ajax/ensembl/Debug",
+	"win32/DLLs/ajax/ensembl/Release",
+	"win32/DLLs/ajax/ajaxdb/Debug",
+	"win32/DLLs/ajax/ajaxdb/Release",
+	"win32/DLLs/ajax/acd/Debug",
+	"win32/DLLs/ajax/acd/Release",
 	"win32/DLLs/nucleus",
 	"win32/DLLs/nucleus/Debug",
 	"win32/DLLs/nucleus/Release",
@@ -635,6 +1006,11 @@ static void create_directories(char *basedir)
 	"win32/apps/release",
 	"win32/apps/emboss",
 	"win32/apps/_UpgradeReport_Files",
+	"win32/mysql",
+	"win32/mysql/include",
+ 	"win32/mysql/include/mysql",
+	"win32/mysql/Debug",
+	"win32/mysql/Release",
 	NULL
     };
     int i;
@@ -791,7 +1167,7 @@ static void extract_funcnames(char *filename, FILE *fout)
 
 
 
-static void write_ajaxexports(char *fn,char *basedir)
+static void write_coreexports(char *fn,char *basedir)
 {
     FILE *outf;
     FILE *inf;
@@ -804,7 +1180,7 @@ static void write_ajaxexports(char *fn,char *basedir)
     system(command);
     unlink(fn);
 
-    sprintf(filename,"%s/win32/DLLs/ajax/%s",basedir,AJAXDEF);
+    sprintf(filename,"%s/win32/DLLs/ajax/core/%s",basedir,COREDEF);
     if(!(outf=fopen(filename,"w")))
     {
 	fprintf(stderr,"Cannot open AJAX definitions file %s\n",filename);
@@ -838,6 +1214,50 @@ static void write_ajaxexports(char *fn,char *basedir)
 
 
 
+static void write_genajaxexport(char *fn,char *basedir,char *exportdef,
+                                char *subdir,char *dllname)
+{
+    FILE *outf;
+    FILE *inf;
+    
+    char command[MAXNAMLEN];
+    char line[MAXNAMLEN];
+    char filename[MAXNAMLEN];
+    
+    sprintf(command,"sort %s > %s",fn, TMPFILE2);
+    system(command);
+    unlink(fn);
+
+    sprintf(filename,"%s/win32/DLLs/ajax/%s/%s",basedir,subdir,exportdef);
+    if(!(outf=fopen(filename,"w")))
+    {
+	fprintf(stderr,"Cannot open %s definitions file %s\n",subdir,filename);
+	exit(-1);
+    }
+
+    fprintf(outf,"LIBRARY \t""%s.dll""\n\n",dllname);
+    fprintf(outf,"EXPORTS\n");
+
+    if(!(inf=fopen(TMPFILE2,"r")))
+    {
+	fprintf(stderr,"Cannot open sorted function file %s\n",TMPFILE2);
+	exit(-1);
+    }
+    
+    while(fgets(line,MAXNAMLEN,inf))
+	fprintf(outf,"\t%s",line);
+	
+    fclose(inf);
+    fclose(outf);
+
+    unlink(TMPFILE2);
+
+    return;
+}
+
+
+
+
 static void write_nucleusexports(char *fn,char *basedir)
 {
     FILE *outf;
@@ -942,7 +1362,9 @@ static int copy_apps(char *basedir, listnode *head)
     char filename[MAXNAMLEN];
     struct stat buf;
     int count;
-
+    int i;
+    int excluded = 0;
+    
     fprintf(stdout,"Copying applications\n");
     
     sprintf(dir,"%s/emboss/emboss",basedir);
@@ -977,8 +1399,22 @@ static int copy_apps(char *basedir, listnode *head)
 	    if(strcmp(dp->d_name + len -2,".c"))
 		continue;
 
+            i = 0;
+            excluded = 0;
+            while(exclude_names[i])
+            {
+                if(!strcmp(dp->d_name,exclude_names[i]))
+                {
+                    excluded = 1;
+                    break;
+                }
+
+                ++i;
+            }
+
+            if(excluded)
+                continue;
 
-	    
 	    ignore = 0;
 	    listptr = head;
 	    while(listptr->next)
@@ -1223,7 +1659,9 @@ static void read_prognames(char *basedir, int napps, char ***names)
     char dir[MAXNAMLEN];
     char **pnames = NULL;
     int i;
-
+    int j;
+    int excluded = 0;
+    
     fprintf(stdout,"Reading program names\n");
 
     *names = (char **) malloc(sizeof(char **) * napps);
@@ -1265,8 +1703,25 @@ static void read_prognames(char *basedir, int napps, char ***names)
 	if(!strcmp(dp->d_name,".")  || !strcmp(dp->d_name,".."))
 	    continue;
 #endif
-	len = strlen(dp->d_name);
-	if(len > 2 && !strcmp(dp->d_name + len - 2, ".c"))
+
+        j = 0;
+        excluded = 0;
+        while(exclude_names[j])
+        {
+            if(!strcmp(dp->d_name,exclude_names[j]))
+            {
+                printf("Found %s\n",dp->d_name);
+                
+                excluded = 1;
+                break;
+            }
+
+            ++j;
+        }
+        
+
+        len = strlen(dp->d_name);
+	if(len > 2 && !strcmp(dp->d_name + len - 2, ".c") && !excluded)
 	{
 	    sprintf(filename,"%s",dp->d_name);
 	    filename[len-2] = '\0';
@@ -1507,3 +1962,240 @@ static void sub_text(char *line, char *tline, char *given, char *rep)
 
     return;
 }
+
+
+
+static void make_ajax_header_exports(char *basedir,char *subdir)
+{
+    char defsdir[MAXNAMLEN];
+    FILE *fp = NULL;
+    
+
+    sprintf(defsdir,"%s/emboss/ajax/%s",basedir,subdir);
+    
+    if(!(fp=fopen(TMPFILE,"w")))
+    {
+	fprintf(stderr,"Cannot open temporary file %s\n",TMPFILE);
+	exit(-1);
+    }
+    
+
+    if(header_exports(defsdir,fp) < 0)
+    {
+	fprintf(stderr,"Cannot open directory %s/emboss/ajax/%s",basedir,
+                subdir);
+	exit(-1);
+    }
+
+    fclose(fp);
+
+    return;
+}
+
+
+
+
+static void make_expat_header_exports(char *basedir)
+{
+    char hfname[MAXNAMLEN];
+    FILE *fp = NULL;
+    
+
+    sprintf(hfname,"%s/emboss/ajax/expat/expat.h",basedir);
+
+
+    if(!(fp=fopen(TMPFILE,"w")))
+    {
+	fprintf(stderr,"Cannot open temporary file %s\n",TMPFILE);
+	exit(-1);
+    }
+
+    extract_expat_funcnames(hfname,fp);
+
+    fclose(fp);
+    
+    return;
+}
+
+
+
+
+static void extract_expat_funcnames(char *filename, FILE *fout)
+{
+    FILE *inf;
+    char line[MAXNAMLEN];
+    char tline[MAXNAMLEN];
+    char command[MAXNAMLEN];
+    
+    int found = 0;
+    char *p;
+    char *q;
+    int len;
+    
+
+    if(!(inf=fopen(filename,"r")))
+    {
+	fprintf(stderr,"Cannot open header file %s\n",filename);
+	exit(-1);
+    }
+
+
+    while(fgets(line,MAXNAMLEN,inf))
+    {
+	if(!strstr(line,"XMLPARSEAPI"))
+	    continue;
+
+        if(!fgets(line,MAXNAMLEN,inf))
+        {
+            fprintf(stderr,"Error in expat.h: expected line after "
+                    "XMLPARSEAPI\n");
+            exit(1);
+        }
+
+	/*
+	** Expects start of a function definition here so looks for
+	** an opening parenthesis. Exits if not found
+        */
+	p = line;
+	while(*p && *p!='(')
+	    ++p;
+	if(!*p)
+	{
+	    fprintf(stderr,"Cannot find '(' in line:\n%s",line);
+	    exit(-1);
+	}
+
+	/* Find last character of function name */
+	--p;
+	while(*p == ' ' || *p == '\t')
+	    --p;
+	
+	q = p;
+
+	/* Find start character of function name */
+	while(*p != ' ' && *p != '\t' && p != line)
+	    --p;
+
+        if(p != line)
+            ++p;
+
+	while(*p=='*')
+	    ++p;
+
+	len = q - p + 1;
+
+	strncpy(tline,p,len);
+	tline[len] = '\0';
+
+	fprintf(fout,"e%s\n",tline);
+    }
+
+    fclose(inf);
+
+    return;
+}
+
+
+
+
+static void make_zlib_header_exports(char *basedir)
+{
+    char hfname[MAXNAMLEN];
+    FILE *fp = NULL;
+    
+
+    sprintf(hfname,"%s/emboss/ajax/zlib/zlib.h",basedir);
+
+
+    if(!(fp=fopen(TMPFILE,"w")))
+    {
+	fprintf(stderr,"Cannot open temporary file %s\n",TMPFILE);
+	exit(-1);
+    }
+
+    extract_zlib_funcnames(hfname,fp);
+
+    fclose(fp);
+    
+    return;
+}
+
+
+
+
+static void extract_zlib_funcnames(char *filename, FILE *fout)
+{
+    FILE *inf;
+    char line[MAXNAMLEN];
+    char tline[MAXNAMLEN];
+    char command[MAXNAMLEN];
+    
+    int found = 0;
+    char *p;
+    char *q;
+    int len;
+    
+
+    if(!(inf=fopen(filename,"r")))
+    {
+	fprintf(stderr,"Cannot open header file %s\n",filename);
+	exit(-1);
+    }
+
+
+    while(fgets(line,MAXNAMLEN,inf))
+    {
+        if(!strncmp(line,"/*",2))
+        {
+            while(strncmp(line,"*/",2))
+                if(!fgets(line,MAXNAMLEN,inf))
+                {
+                    fprintf(stderr,"extract_zlib_funcnames: Can't find /*\n");
+                    exit(1);
+                }
+            
+            continue;
+        }
+
+        if(!strstr(line,"ZEXTERN"))
+	    continue;
+
+	/*
+	** Expects start of a function definition here so looks for
+	** "OF(". Exits if not found
+        */
+        p = strstr(line,"OF(");
+	if(!p)
+	{
+	    fprintf(stderr,"Cannot find 'OF(' in line:\n%s",line);
+	    exit(-1);
+	}
+
+	/* Find last character of function name */
+	--p;
+	while(*p == ' ' || *p == '\t')
+	    --p;
+	
+	q = p;
+
+	/* Find start character of function name */
+	while(*p != ' ' && *p != '\t' && p != line)
+	    --p;
+
+        ++p;
+
+	while(*p=='*')
+	    ++p;
+
+	len = q - p + 1;
+
+	strncpy(tline,p,len);
+	tline[len] = '\0';
+
+	fprintf(fout,"e%s\n",tline);
+    }
+
+    fclose(inf);
+
+    return;
+}
