@@ -58,7 +58,7 @@ if (!defined $application || $application eq "") {
 }
 
 # where the web pages and include files live
-$doctop = "$ENV{HOME}/cvsemboss";
+$doctop = "$ENV{HOME}/devemboss";
 if ($embassy eq "") {
     $docdir = "$doctop/doc/programs/master/emboss/apps";
     $incdir = "$docdir/inc";
@@ -603,7 +603,7 @@ test $dotest hasn't used ", $#answers+1, " answers\n";
 		$rotate = "-90<";
 		if(defined($rotations{$pname})){
 		    $rotate = $rotations{$pname};
-		    print STDERR "rotate '$rotate'\n";
+#		    print STDERR "rotate '$rotate'\n";
 		}
 # add -delay to see the first page of an animated gif for 10 mins
 		# add -delay to see the first page of an animated gif for 10 mins
@@ -798,7 +798,7 @@ sub writeUsage {
 
     my $out = "$incdir/$application.usage";
     open (OUT, "> $out") || die "Can't open $out";
-    $usage =~ s/\/homes\/pmr\/cvsemboss/\/homes\/user/go;
+    $usage =~ s/\/homes\/pmr\/devemboss/\/homes\/user/go;
     $usage =~ s/(Guide tree +file created: +)\[[A-Z0-9]+\]/$1\[12345678A]/go;
     $usage =~ s/(GCG-Alignment file created +)\[[A-Z0-9]+\]/$1\[12345678A]/go;
     $usage =~ s/domainalign\-[0-9]+[.][0-9]+/domainalign-1234567890.1234/go;
@@ -809,8 +809,8 @@ sub writeUsage {
     $usage =~ s/seqsearch\-[0-9]+[.][0-9]+[.]/seqsearch-1234567890.1234./go;
     $usage =~ s/hmmalign\-[0-9]+[.][0-9]+/hmmalign-1234567890.1234/go;
     $usage =~ s/hmmpfam\-[0-9]+[.][0-9]+/hmmpfam-1234567890.1234/go;
-    $usage =~ s/Localtime: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/Localtime: Tue Jul 15 12:00:00 2008/gom;
-    $usage =~ s/SUBMITTED iprscan-\d+-\d+/SUBMITTED-iprscan-20080715-12345678/go;
+    $usage =~ s/Localtime: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/Localtime: Fri Jan 15 12:00:00 2010/gom;
+    $usage =~ s/SUBMITTED iprscan-\d+-\d+/SUBMITTED-iprscan-20100115-12345678/go;
     print OUT $usage;
     close(OUT);
     chmod 0664, $out;	# rw-rw-r--
@@ -827,7 +827,7 @@ sub writeInput {
 
     my $out = "$incdir/$application.input";
     open (OUT, "> $out") || die "Can't open $out";
-    $input =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Tue Jul 15 12:00:00 2008/go;
+    $input =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Fri Jan 15 12:00:00 2010/go;
     print OUT $input;
     close(OUT);
     chmod 0664, $out;	# rw-rw-r--
@@ -844,12 +844,12 @@ sub writeOutput {
 
     my $out = "$incdir/$application.output";
     open (OUT, "> $out") || die "Can't open $out";
-    $output =~ s/\/homes\/pmr\/cvsemboss/\/homes\/user/go;
-    $output =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Tue Jul 15 12:00:00 2008/go;
-    $output =~ s/CreationDate: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/CreationDate: Tue Jul 15 12:00:00 2008/gom;
-    $output =~ s/Rundate: ... ... +\d+ 2[0-9][0-9][0-9] [0-9:]+$/Rundate: Tue Jul 15 2008 12:00:00/gom;
-    $output =~ s/Localtime: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/Localtime: Tue Jul 15 12:00:00 2008/gom;
-    $output =~ s/\#\#date 2[0-9][0-9][0-9][-][0-9][0-9][-][0-9][0-9]$/\#\#date 2008-07-15/gom;
+    $output =~ s/\/homes\/pmr\/devemboss/\/homes\/user/go;
+    $output =~ s/DATE  [A-Z][a-z][a-z] [A-Z][a-z][a-z] +[0-9]+ [0-9:]+ 200[5-9]/DATE  Fri Jan 15 12:00:00 2010/go;
+    $output =~ s/CreationDate: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/CreationDate: Fri Jan 15 12:00:00 2010/gom;
+    $output =~ s/Rundate: ... ... +\d+ 2[0-9][0-9][0-9] [0-9:]+$/Rundate: Fri Jan 15 2010 12:00:00/gom;
+    $output =~ s/Localtime: ... ... +\d+ [0-9:]+ 2[0-9][0-9][0-9]$/Localtime: Fri Jan 15 12:00:00 2010/gom;
+    $output =~ s/\#\#date 2[0-9][0-9][0-9][-][0-9][0-9][-][0-9][0-9]$/\#\#date 2010-01-15/gom;
     $output =~ s/domainalign\-[0-9]+[.][0-9]+[.]/domainalign-1234567890.1234./go;
     $output =~ s/domainrep\-[0-9]+[.][0-9]+[.]/domainrep-1234567890.1234./go;
     $output =~ s/seqalign\-[0-9]+[.][0-9]+[.]/seqalign-1234567890.1234./go;
@@ -857,7 +857,9 @@ sub writeOutput {
     $output =~ s/hmmalign\-[0-9]+[.][0-9]+/hmmalign-1234567890.1234/go;
     $output =~ s/hmmpfam\-[0-9]+[.][0-9]+/hmmpfam-1234567890.1234/go;
     $output =~ s/Time 0\.00[1-5][0-9][0-9][0-9] secs\./Time 0.001999 secs./go;
-    $output =~ s/\%\%Creator: (\S+ [\d.]+) 2[0-9][0-9][0-9]\/[0-9[0-9]\/[0-9[0-9]/Creator: $1 2008\/07\/15/go;
+    $output =~ s/\%\%Creator: (\S+ [\d.]+) 2[0-9][0-9][0-9]\/[0-9[0-9]\/[0-9[0-9]/Creator: $1 2010\/01\/15/go;
+    $output =~ s/mse\.msf MSF: 120 Type: N \d+\/\d+\/\d+ CompCheck: 2784/mse.msf MSF: 120 Type: N 15\/07\/09 CompCheck: 2784/go;
+    $output =~ s/   \d+-[A-Z][a-z][a-z]-2[01][0-9][0-9]   /   15-Jan-2010   /go;
     print OUT $output;
     close(OUT);
     chmod 0664, $out;	# rw-rw-r--
